@@ -546,6 +546,7 @@ static void CG_DrawStatusBar( void ) {
 	vec4_t		hcolor;
 	vec3_t		angles;
 	vec3_t		origin;
+        qhandle_t	handle;
         
 	static float colors[4][4] = { 
 //		{ 0.2, 1.0, 0.2, 1.0 } , { 1.0, 0.2, 0.2, 1.0 }, {0.5, 0.5, 0.5, 1} };
@@ -597,6 +598,21 @@ static void CG_DrawStatusBar( void ) {
 		CG_Draw3DModel( 370 + CHAR_WIDTH*3 + TEXT_ICON_SPACE, 432, ICON_SIZE, ICON_SIZE,
 					   cgs.media.armorModel, 0, origin, angles );
 	}
+        
+        if( cgs.gametype == GT_HARVESTER ) {
+		origin[0] = 90;
+		origin[1] = 0;
+		origin[2] = -10;
+		angles[YAW] = ( cg.time & 2047 ) * 360 / 2048.0;
+		if( cg.snap->ps.persistant[PERS_TEAM] == TEAM_BLUE ) {
+			handle = cgs.media.redCubeModel;
+		} else {
+			handle = cgs.media.blueCubeModel;
+		}
+		CG_Draw3DModel( 470 + CHAR_WIDTH*3 + TEXT_ICON_SPACE, 432, ICON_SIZE, ICON_SIZE, handle, 0, origin, angles );
+	}
+        
+        
 	//
 	// ammo
 	//
@@ -666,6 +682,27 @@ static void CG_DrawStatusBar( void ) {
 		}
 
 	}
+        
+        //Skulls!
+        if(cgs.gametype == GT_HARVESTER)
+        {
+            value = ps->generic1;
+            if (value > 0 ) {
+                    trap_R_SetColor( colors[0] );
+                    CG_DrawField (470, 432, 3, value);
+                    trap_R_SetColor( NULL );
+                    // if we didn't draw a 3D icon, draw a 2D icon for skull
+                    if ( !cg_draw3dIcons.integer && cg_drawIcons.integer ) {
+                            if( cg.snap->ps.persistant[PERS_TEAM] == TEAM_BLUE ) {
+                                    handle = cgs.media.redCubeIcon;
+                            } else {
+                                    handle = cgs.media.blueCubeIcon;
+                            }
+                            CG_DrawPic( 470 + CHAR_WIDTH*3 + TEXT_ICON_SPACE, 432, ICON_SIZE, ICON_SIZE, handle );
+                    }
+
+            }
+        }
 }
 #endif
 
@@ -746,7 +783,7 @@ static float CG_DrawSpeedMeter( float y ) {
 	/* ignore vertical component of velocity */
 	speed = sqrt(vel[0] * vel[0] + vel[1] * vel[1]);
 
-	s = va( "%i u/s", speed );
+	s = va( "%iu/s", speed );
 
 	w = CG_DrawStrlen( s ) * BIGCHAR_WIDTH;
 
@@ -852,9 +889,11 @@ static float CG_DrawTimer( float y ) {
 
 /*
 CG_DrawDoubleDominationThings
+ *
+ *Sago: Might be relevant for debugging missionpack.
 */
 
-static float CG_DrawDoubleDominationThings( float y ) {
+/*static float CG_DrawDoubleDominationThings( float y ) {
 	char		*s;
 	int			w;
 	int 		statusA, statusB;
@@ -903,7 +942,7 @@ static float CG_DrawDoubleDominationThings( float y ) {
 	}
 
 	return y + SMALLCHAR_HEIGHT+4;
-}
+}*/
 
 /*
 =================
@@ -951,7 +990,7 @@ static float CG_DrawCTFoneway( float y ) {
 
 	memcpy(color,g_color_table[ColorIndex(COLOR_WHITE)],sizeof(color));
 
-	if(cgs.oneway == 0) {
+	if( (cgs.elimflags&EF_ONEWAY)==0) {
 		return y; //nothing to draw
 	} else
 	if(cgs.attackingTeam == TEAM_BLUE) {
@@ -1037,9 +1076,15 @@ static float CG_DrawEliminationTimer( float y ) {
 	float scale;
 	int cw;
 	int rst;
-	
+
+        
+
 	rst = cgs.roundStartTime;
 
+        if(cg.time>rst && !cgs.roundtime) {
+            return y;
+        }
+
 	//default color is white
 	memcpy(color,g_color_table[ColorIndex(COLOR_WHITE)],sizeof(color));
 
@@ -1106,8 +1151,9 @@ Lots of stuff
 			//w = CG_Text_Width(s, scale, 0);
 			//CG_Text_Paint(320 - w / 2, 125, scale, colorWhite, st, 0, 0, ITEM_TEXTSTYLE_SHADOWEDMORE);
 	#else
-		w = CG_DrawStrlen( st );
-		CG_DrawStringExt( 320 - w * cw/2, 70, st, colorWhite, 
+                
+                    w = CG_DrawStrlen( st );
+                    CG_DrawStringExt( 320 - w * cw/2, 70, st, colorWhite,
 				qfalse, qtrue, cw, (int)(cw * 1.5), 0 );
 	#endif
 	}
@@ -1311,7 +1357,7 @@ static float CG_DrawFollowMessage( float y ) {
 	char		*s;
 	int			w;	
 
-	if ( !(cg.snap->ps.pm_flags & PMF_FOLLOW) ) {
+	if ( !(cg.snap->ps.pm_flags & PMF_FOLLOW) || ( ( cgs.elimflags & EF_NO_FREESPEC ) && (cgs.gametype == GT_ELIMINATION || cgs.gametype == GT_CTF_ELIMINATION ) ) ) {
 		return y;
 	}
 
@@ -1329,7 +1375,8 @@ CG_DrawUpperRight
 
 =====================
 */
-static void CG_DrawUpperRight( void ) {
+static void CG_DrawUpperRight(stereoFrame_t stereoFrame)
+{
 	float	y;
 
 	y = 0;
@@ -1337,10 +1384,10 @@ static void CG_DrawUpperRight( void ) {
 	if ( cgs.gametype >= GT_TEAM && cgs.ffa_gt!=1 && cg_drawTeamOverlay.integer == 1 ) {
 		y = CG_DrawTeamOverlay( y, qtrue, qtrue );
 	}
-	if ( cgs.gametype == GT_DOUBLE_D ) {
+	/*if ( cgs.gametype == GT_DOUBLE_D ) {
 		y = CG_DrawDoubleDominationThings(y);
 	} 
-	else
+	else*/
 	if ( cgs.gametype == GT_LMS && cg.showScores ) {
 		y = CG_DrawLMSmode(y);
 	}
@@ -1356,7 +1403,7 @@ static void CG_DrawUpperRight( void ) {
 	if ( cg_drawSnapshot.integer ) {
 		y = CG_DrawSnapshot( y );
 	}
-	if ( cg_drawFPS.integer ) {
+	if (cg_drawFPS.integer && (stereoFrame == STEREO_CENTER || stereoFrame == STEREO_RIGHT)) {
 		y = CG_DrawFPS( y );
 	}
 	if (cgs.gametype==GT_ELIMINATION || cgs.gametype == GT_CTF_ELIMINATION || cgs.gametype==GT_LMS) {
@@ -1403,6 +1450,10 @@ static float CG_DrawScores( float y ) {
 	vec4_t		color;
 	float		y1;
 	gitem_t		*item;
+        int statusA,statusB;
+        
+        statusA = cgs.redflag;
+        statusB = cgs.blueflag;
 
 	s1 = cgs.scores1;
 	s2 = cgs.scores2;
@@ -1438,6 +1489,16 @@ static float CG_DrawScores( float y ) {
 				}
 			}
 		}
+                
+                if ( cgs.gametype == GT_DOUBLE_D ) {
+			// Display Domination point status
+			
+				y1 = y - 32;//BIGCHAR_HEIGHT - 8;
+				if( cgs.redflag >= 0 && cgs.redflag <= 3 ) {
+					CG_DrawPic( x, y1-4, w, 32, cgs.media.ddPointSkinB[cgs.blueflag] );
+				}
+		}
+                
 		color[0] = 1.0f;
 		color[1] = 0.0f;
 		color[2] = 0.0f;
@@ -1462,6 +1523,32 @@ static float CG_DrawScores( float y ) {
 				}
 			}
 		}
+                
+                if ( cgs.gametype == GT_DOUBLE_D ) {
+			// Display Domination point status
+			
+				y1 = y - 32;//BIGCHAR_HEIGHT - 8;
+				if( cgs.redflag >= 0 && cgs.redflag <= 3 ) {
+					CG_DrawPic( x, y1-4, w, 32, cgs.media.ddPointSkinA[cgs.redflag] );
+				}
+                                
+                        
+                                
+                        //Time till capture:
+                        if( ( ( statusB == statusA ) && ( statusA == TEAM_RED ) ) ||
+                            ( ( statusB == statusA ) && ( statusA == TEAM_BLUE ) ) ) {
+                                s = va("%i",(cgs.timetaken+10*1000-cg.time)/1000+1);
+                                w = CG_DrawStrlen( s ) * BIGCHAR_WIDTH;
+                                CG_DrawBigString( x + 32+8-w/2, y-28, s, 1.0F);
+                        }
+		}
+                
+                if ( cgs.gametype == GT_OBELISK ) {
+                    s = va("^1%3i%% ^4%3i%%",cg.redObeliskHealth,cg.blueObeliskHealth);
+                    CG_DrawSmallString( x, y-28, s, 1.0F);
+                }
+                
+                
 
 		if ( cgs.gametype >= GT_CTF && cgs.ffa_gt==0) {
 			v = cgs.capturelimit;
@@ -1584,6 +1671,10 @@ static float CG_DrawPowerups( float y ) {
 			continue;
 		}
 
+                item = BG_FindItemForPowerup( i );
+                if ( item && item->giType == IT_PERSISTANT_POWERUP)
+                    continue; //Don't draw persistant powerups here!
+
 		// insert into the list
 		for ( j = 0 ; j < active ; j++ ) {
 			if ( sortedTime[j] >= t ) {
@@ -1811,13 +1902,13 @@ static void CG_DrawHoldableItem( void ) {
 }
 #endif // MISSIONPACK
 
-#ifdef MISSIONPACK
+#ifndef MISSIONPACK
 /*
 ===================
 CG_DrawPersistantPowerup
 ===================
 */
-#if 0 // sos001208 - DEAD
+#if 1 // sos001208 - DEAD // sago - ALIVE
 static void CG_DrawPersistantPowerup( void ) { 
 	int		value;
 
@@ -1851,13 +1942,16 @@ static void CG_DrawReward( void ) {
 		if (cg.rewardStack > 0) {
 			for(i = 0; i < cg.rewardStack; i++) {
 				cg.rewardSound[i] = cg.rewardSound[i+1];
+				
 				cg.rewardShader[i] = cg.rewardShader[i+1];
 				cg.rewardCount[i] = cg.rewardCount[i+1];
 			}
 			cg.rewardTime = cg.time;
 			cg.rewardStack--;
 			color = CG_FadeColor( cg.rewardTime, REWARD_TIME );
-			trap_S_StartLocalSound(cg.rewardSound[0], CHAN_ANNOUNCER);
+			
+			trap_S_StartLocalSound(cg.rewardSound[0], CHAN_ANNOUNCER);  
+
 		} else {
 			return;
 		}
@@ -2225,6 +2319,130 @@ static void CG_DrawCenterString( void ) {
 	trap_R_SetColor( NULL );
 }
 
+/*
+=====================
+CG_DrawCenter1FctfString
+=====================
+*/
+static void CG_DrawCenter1FctfString( void ) {
+    #ifndef MISSIONPACK
+    int		x, y, w;
+    float       *color;
+    char        *line;
+    int status;
+    
+    if(cgs.gametype != GT_1FCTF)
+        return;
+    
+    status = cgs.flagStatus;
+    
+    //Sago: TODO: Find the proper defines instead of hardcoded values.
+    switch(status)
+    {
+        case 2:
+            line = va("Red has the flag!");
+            color = colorRed;
+            break;
+        case 3:
+            line = va("Blue has the flag!");
+            color = colorBlue;
+            break;
+        case 4:
+            line = va("Flag dropped!");
+            color = colorWhite;
+            break;
+        default:
+            return;
+            
+    };
+    y = 100;
+    
+    
+    w = cg.centerPrintCharWidth * CG_DrawStrlen( line );
+
+    x = ( SCREEN_WIDTH - w ) / 2;
+
+    CG_DrawStringExt( x, y, line, color, qfalse, qtrue,
+		cg.centerPrintCharWidth, (int)(cg.centerPrintCharWidth * 1.5), 0 );
+    
+    
+    #endif
+}
+
+
+
+/*
+=====================
+CG_DrawCenterDDString
+=====================
+*/
+static void CG_DrawCenterDDString( void ) {
+    #ifndef MISSIONPACK
+    int		x, y, w;
+    float       *color;
+    char        *line;
+    int 		statusA, statusB;
+    int sec;
+    static int lastDDSec = -100;
+
+    
+    if(cgs.gametype != GT_DOUBLE_D)
+        return;
+    
+    	statusA = cgs.redflag;
+	statusB = cgs.blueflag;
+    
+    if( ( ( statusB == statusA ) && ( statusA == TEAM_RED ) ) ||
+            ( ( statusB == statusA ) && ( statusA == TEAM_BLUE ) ) ) {
+      }
+    else
+        return; //No team is dominating
+    
+    if(statusA == TEAM_BLUE) {
+        line = va("Blue scores in %i",(cgs.timetaken+10*1000-cg.time)/1000+1);
+        color = colorBlue;
+    } else if(statusA == TEAM_RED) {
+        line = va("Red scores in %i",(cgs.timetaken+10*1000-cg.time)/1000+1);
+        color = colorRed;
+    } else {
+        lastDDSec = -100;
+        return;
+    }
+
+    sec = (cgs.timetaken+10*1000-cg.time)/1000+1;
+    if(sec!=lastDDSec) {
+        //A new number is being displayed... play the sound!
+        switch ( sec ) {
+            case 1:
+                trap_S_StartLocalSound( cgs.media.count1Sound, CHAN_ANNOUNCER );
+                break;
+            case 2:
+                trap_S_StartLocalSound( cgs.media.count2Sound, CHAN_ANNOUNCER );
+                break;
+            case 3:
+                trap_S_StartLocalSound( cgs.media.count3Sound, CHAN_ANNOUNCER );
+                break;
+            case 10:
+                trap_S_StartLocalSound( cgs.media.doublerSound , CHAN_ANNOUNCER );
+                break;
+            default:
+                break;
+        }
+    }
+    lastDDSec = sec;
+    
+    y = 100;
+    
+    
+    w = cg.centerPrintCharWidth * CG_DrawStrlen( line );
+
+    x = ( SCREEN_WIDTH - w ) / 2;
+
+    CG_DrawStringExt( x, y, line, color, qfalse, qtrue,
+		cg.centerPrintCharWidth, (int)(cg.centerPrintCharWidth * 1.5), 0 );
+    
+    #endif
+}
 
 
 /*
@@ -2241,12 +2459,16 @@ CROSSHAIR
 CG_DrawCrosshair
 =================
 */
-static void CG_DrawCrosshair(void) {
+static void CG_DrawCrosshair(void)
+{
 	float		w, h;
 	qhandle_t	hShader;
 	float		f;
 	float		x, y;
-	int			ca;
+	int			ca = 0; //only to get rid of the warning(not useful)
+	int 		currentWeapon;
+	
+	currentWeapon = cg.predictedPlayerState.weapon;
 
 	if ( !cg_drawCrosshair.integer ) {
 		return;
@@ -2267,7 +2489,134 @@ static void CG_DrawCrosshair(void) {
 		CG_ColorForHealth( hcolor );
 		trap_R_SetColor( hcolor );
 	} else {
-		trap_R_SetColor( NULL );
+                vec4_t         color;
+                color[0]=cg_crosshairColorRed.value;
+                color[1]=cg_crosshairColorGreen.value;
+                color[2]=cg_crosshairColorBlue.value;
+                color[3]=1.0f;
+		trap_R_SetColor( color );
+	}
+
+	if( cg_differentCrosshairs.integer == 1 ){
+		switch( currentWeapon ){
+			case 1:
+				w = h = cg_ch1size.value;
+				ca = cg_ch1.integer;
+				break;
+			case 2:
+				w = h = cg_ch2size.value;
+				ca = cg_ch2.integer;
+				break;
+			case 3:
+				w = h = cg_ch3size.value;
+				ca = cg_ch3.integer;
+				break;
+			case 4:
+				w = h = cg_ch4size.value;
+				ca = cg_ch4.integer;
+				break;
+			case 5:
+				w = h = cg_ch5size.value;
+				ca = cg_ch5.integer;
+				break;
+			case 6:
+				w = h = cg_ch6size.value;
+				ca = cg_ch6.integer;
+				break;
+			case 7:
+				w = h = cg_ch7size.value;
+				ca = cg_ch7.integer;
+				break;
+			case 8:
+				w = h = cg_ch8size.value;
+				ca = cg_ch8.integer;
+				break;
+			case 9:
+				w = h = cg_ch9size.value;
+				ca = cg_ch9.integer;
+				break;
+			case 10:
+				w = h = cg_ch10size.value;
+				ca = cg_ch10.integer;
+				break;
+			case 11:
+				w = h = cg_ch11size.value;
+				ca = cg_ch11.integer;
+				break;
+			case 12:
+				w = h = cg_ch12size.value;
+				ca = cg_ch12.integer;
+				break;
+			case 13:
+				w = h = cg_ch13size.value;
+				ca = cg_ch13.integer;
+				break;
+                        default:
+                                w = h = cg_crosshairSize.value;
+                                ca = cg_drawCrosshair.integer;
+                                break;
+		}
+	}
+	else{
+		w = h = cg_crosshairSize.value;
+		ca = cg_drawCrosshair.integer;
+	}
+	
+	if( cg_crosshairPulse.integer ){
+		// pulse the size of the crosshair when picking up items
+		f = cg.time - cg.itemPickupBlendTime;
+		if ( f > 0 && f < ITEM_BLOB_TIME ) {
+			f /= ITEM_BLOB_TIME;
+			w *= ( 1 + f );
+			h *= ( 1 + f );
+		}
+	}
+
+	x = cg_crosshairX.integer;
+	y = cg_crosshairY.integer;
+	CG_AdjustFrom640( &x, &y, &w, &h );
+
+	if (ca < 0) {
+		ca = 0;
+	}
+	hShader = cgs.media.crosshairShader[ ca % NUM_CROSSHAIRS ];
+
+        if(!hShader)
+            hShader = cgs.media.crosshairShader[ ca % 10 ];
+
+	trap_R_DrawStretchPic( x + cg.refdef.x + 0.5 * (cg.refdef.width - w), 
+		y + cg.refdef.y + 0.5 * (cg.refdef.height - h), 
+		w, h, 0, 0, 1, 1, hShader );
+}
+
+/*
+=================
+CG_DrawCrosshair3D
+=================
+*/
+static void CG_DrawCrosshair3D(void)
+{
+	float		w, h;
+	qhandle_t	hShader;
+	float		f;
+	int			ca;
+
+	trace_t trace;
+	vec3_t endpos;
+	float stereoSep, zProj, maxdist, xmax;
+	char rendererinfos[128];
+	refEntity_t ent;
+
+	if ( !cg_drawCrosshair.integer ) {
+		return;
+	}
+
+	if ( cg.snap->ps.persistant[PERS_TEAM] == TEAM_SPECTATOR) {
+		return;
+	}
+
+	if ( cg.renderingThirdPerson ) {
+		return;
 	}
 
 	w = h = cg_crosshairSize.value;
@@ -2280,19 +2629,43 @@ static void CG_DrawCrosshair(void) {
 		h *= ( 1 + f );
 	}
 
-	x = cg_crosshairX.integer;
-	y = cg_crosshairY.integer;
-	CG_AdjustFrom640( &x, &y, &w, &h );
-
 	ca = cg_drawCrosshair.integer;
 	if (ca < 0) {
 		ca = 0;
 	}
 	hShader = cgs.media.crosshairShader[ ca % NUM_CROSSHAIRS ];
 
-	trap_R_DrawStretchPic( x + cg.refdef.x + 0.5 * (cg.refdef.width - w), 
-		y + cg.refdef.y + 0.5 * (cg.refdef.height - h), 
-		w, h, 0, 0, 1, 1, hShader );
+        if(!hShader)
+            hShader = cgs.media.crosshairShader[ ca % 10 ];
+
+	// Use a different method rendering the crosshair so players don't see two of them when
+	// focusing their eyes at distant objects with high stereo separation
+	// We are going to trace to the next shootable object and place the crosshair in front of it.
+
+	// first get all the important renderer information
+	trap_Cvar_VariableStringBuffer("r_zProj", rendererinfos, sizeof(rendererinfos));
+	zProj = atof(rendererinfos);
+	trap_Cvar_VariableStringBuffer("r_stereoSeparation", rendererinfos, sizeof(rendererinfos));
+	stereoSep = zProj / atof(rendererinfos);
+	
+	xmax = zProj * tan(cg.refdef.fov_x * M_PI / 360.0f);
+	
+	// let the trace run through until a change in stereo separation of the crosshair becomes less than one pixel.
+	maxdist = cgs.glconfig.vidWidth * stereoSep * zProj / (2 * xmax);
+	VectorMA(cg.refdef.vieworg, maxdist, cg.refdef.viewaxis[0], endpos);
+	CG_Trace(&trace, cg.refdef.vieworg, NULL, NULL, endpos, 0, MASK_SHOT);
+	
+	memset(&ent, 0, sizeof(ent));
+	ent.reType = RT_SPRITE;
+	ent.renderfx = RF_DEPTHHACK | RF_CROSSHAIR;
+	
+	VectorCopy(trace.endpos, ent.origin);
+	
+	// scale the crosshair so it appears the same size for all distances
+	ent.radius = w / 640 * xmax * trace.fraction * maxdist / zProj;
+	ent.customShader = hShader;
+
+	trap_R_AddRefEntityToScene(&ent);
 }
 
 
@@ -2317,7 +2690,7 @@ static void CG_ScanForCrosshairEntity( void ) {
 	}
 
 	// if the player is in fog, don't show it
-	content = trap_CM_PointContents( trace.endpos, 0 );
+	content = CG_PointContents( trace.endpos, 0 );
 	if ( content & CONTENTS_FOG ) {
 		return;
 	}
@@ -2436,9 +2809,9 @@ static void CG_DrawTeamVote(void) {
 	char	*s;
 	int		sec, cs_offset;
 
-	if ( cgs.clientinfo->team == TEAM_RED )
+	if ( cgs.clientinfo[cg.clientNum].team == TEAM_RED )
 		cs_offset = 0;
-	else if ( cgs.clientinfo->team == TEAM_BLUE )
+	else if ( cgs.clientinfo[cg.clientNum].team == TEAM_BLUE )
 		cs_offset = 1;
 	else
 		return;
@@ -2528,10 +2901,66 @@ static qboolean CG_DrawScoreboard( void ) {
 
 	return qtrue;
 #else
+        char        *s;
+        int w;
+        if(cg.respawnTime && cg.snap->ps.persistant[PERS_TEAM] != TEAM_SPECTATOR && (cgs.gametype < GT_ELIMINATION || cgs.gametype > GT_LMS) ) {
+            if(cg.respawnTime>cg.time) {
+                s = va("Respawn in: %2.2f",((double)cg.respawnTime-(double)cg.time)/1000.0);
+                w = CG_DrawStrlen( s ) * SMALLCHAR_WIDTH;
+                CG_DrawSmallStringColor(320-w/2,400, s, colorYellow);
+            } else {
+                s = va("Click FIRE to respawn");
+                w = CG_DrawStrlen( s ) * SMALLCHAR_WIDTH;
+                CG_DrawSmallStringColor(320-w/2,400, "Click FIRE to respawn", colorGreen);
+            }
+        }
 	return CG_DrawOldScoreboard();
 #endif
 }
 
+#define ACCBOARD_XPOS 500
+#define ACCBOARD_YPOS 150
+#define ACCBOARD_HEIGHT 20
+#define ACCBOARD_WIDTH 75
+#define ACCITEM_SIZE 16
+
+qboolean CG_DrawAccboard( void ) {
+        int counter, i;
+
+        i = 0;
+
+        if( !cg.showAcc ){
+                return qfalse;
+        }
+        trap_R_SetColor( colorWhite );
+
+        for( counter = 0; counter < WP_NUM_WEAPONS ; counter++ ){
+                if( cg_weapons[counter+2].weaponIcon && counter != WP_PROX_LAUNCHER && counter != WP_GRAPPLING_HOOK )
+                        i++;
+        }
+
+        CG_DrawTeamBackground( ACCBOARD_XPOS, ACCBOARD_YPOS, ACCBOARD_WIDTH, ACCBOARD_HEIGHT*(i + 1), 0.33f, TEAM_BLUE );
+
+        i = 0;
+
+        for( counter = 0 ; counter < WP_NUM_WEAPONS ; counter++ ){
+                if( cg_weapons[counter+2].weaponIcon && counter != WP_PROX_LAUNCHER && counter != WP_GRAPPLING_HOOK ){
+                        CG_DrawPic( ACCBOARD_XPOS + 10, ACCBOARD_YPOS + 10 +i*ACCBOARD_HEIGHT, ACCITEM_SIZE, ACCITEM_SIZE, cg_weapons[counter+2].weaponIcon );
+                        if( cg.accuracys[counter][0] > 0 )
+                                CG_DrawSmallStringColor(ACCBOARD_XPOS + 10 + ACCITEM_SIZE + 10, ACCBOARD_YPOS + 10 +i*ACCBOARD_HEIGHT + ACCITEM_SIZE/2 - SMALLCHAR_HEIGHT/2 ,
+                                         va("%i%s",(int)(((float)cg.accuracys[counter][1]*100)/((float)(cg.accuracys[counter][0]))),"%"), colorWhite);
+                        else
+                                CG_DrawSmallStringColor(ACCBOARD_XPOS + 10 + ACCITEM_SIZE + 10, ACCBOARD_YPOS + 10 +i*ACCBOARD_HEIGHT + ACCITEM_SIZE/2 - SMALLCHAR_HEIGHT/2 , "-%", colorWhite);
+                        i++;
+                }
+        }
+
+        trap_R_SetColor(NULL);
+        return qtrue;
+}
+
+
+
 /*
 =================
 CG_DrawIntermission
@@ -2596,7 +3025,7 @@ static void CG_DrawAmmoWarning( void ) {
 	int			w;
 
 	//Don't report in instant gib same with RA
-	if(cgs.instantgib || cgs.rockets)
+	if(cgs.nopickup)
 		return;
 
 	if ( cg_drawAmmoWarning.integer == 0 ) {
@@ -2617,7 +3046,7 @@ static void CG_DrawAmmoWarning( void ) {
 }
 
 
-#ifdef MISSIONPACK
+//#ifdef MISSIONPACK
 /*
 =================
 CG_DrawProxWarning
@@ -2655,7 +3084,7 @@ static void CG_DrawProxWarning( void ) {
 	w = CG_DrawStrlen( s ) * BIGCHAR_WIDTH;
 	CG_DrawBigStringColor( 320 - w / 2, 64 + BIGCHAR_HEIGHT, s, g_color_table[ColorIndex(COLOR_RED)] );
 }
-#endif
+//#endif
 
 
 /*
@@ -2730,14 +3159,14 @@ static void CG_DrawWarmup( void ) {
 			s = "Last Man Standing";
 		} else if ( cgs.gametype == GT_DOUBLE_D ) {
 			s = "Double Domination";
-#ifdef MISSIONPACK
 		} else if ( cgs.gametype == GT_1FCTF ) {
 			s = "One Flag CTF";
 		} else if ( cgs.gametype == GT_OBELISK ) {
 			s = "Overload";
 		} else if ( cgs.gametype == GT_HARVESTER ) {
 			s = "Harvester";
-#endif
+                } else if ( cgs.gametype == GT_DOMINATION ) {
+			s = "Domination";
 		} else {
 			s = "";
 		}
@@ -2831,7 +3260,8 @@ void CG_DrawTimedMenus( void ) {
 CG_Draw2D
 =================
 */
-static void CG_Draw2D( void ) {
+static void CG_Draw2D(stereoFrame_t stereoFrame)
+{
 #ifdef MISSIONPACK
 	if (cgs.orderPending && cg.time > cgs.orderTime) {
 		CG_CheckOrderPending();
@@ -2858,7 +3288,10 @@ static void CG_Draw2D( void ) {
 */
 	if ( cg.snap->ps.persistant[PERS_TEAM] == TEAM_SPECTATOR /*|| cg.snap->ps.pm_type == PM_SPECTATOR*/ ) {
 		CG_DrawSpectator();
-		CG_DrawCrosshair();
+
+		if(stereoFrame == STEREO_CENTER)
+			CG_DrawCrosshair();
+
 		CG_DrawCrosshairNames();
 	} else {
 		// don't draw any status if dead or the scoreboard is being explicitly shown
@@ -2875,19 +3308,18 @@ static void CG_Draw2D( void ) {
       
 			CG_DrawAmmoWarning();
 
-#ifdef MISSIONPACK
 			CG_DrawProxWarning();
-#endif      
-			CG_DrawCrosshair();
+			if(stereoFrame == STEREO_CENTER)
+				CG_DrawCrosshair();
 			CG_DrawCrosshairNames();
 			CG_DrawWeaponSelect();
 
-#ifndef MISSIONPACK
+                        #ifndef MISSIONPACK
 			CG_DrawHoldableItem();
-#else
-			//CG_DrawPersistantPowerup();
-#endif
-			CG_DrawReward();
+			CG_DrawPersistantPowerup();
+			#endif
+
+                        CG_DrawReward();
 		}
     
 		if ( cgs.gametype >= GT_TEAM && cgs.ffa_gt!=1) {
@@ -2904,10 +3336,10 @@ static void CG_Draw2D( void ) {
 
 #ifdef MISSIONPACK
 	if (!cg_paused.integer) {
-		CG_DrawUpperRight();
+		CG_DrawUpperRight(stereoFrame);
 	}
 #else
-	CG_DrawUpperRight();
+	CG_DrawUpperRight(stereoFrame);
 #endif
 
 #ifndef MISSIONPACK
@@ -2922,8 +3354,12 @@ static void CG_Draw2D( void ) {
 	// don't draw center string if scoreboard is up
 	cg.scoreBoardShowing = CG_DrawScoreboard();
 	if ( !cg.scoreBoardShowing) {
+                CG_DrawCenterDDString();
+                CG_DrawCenter1FctfString();
 		CG_DrawCenterString();
 	}
+
+        cg.accBoardShowing = CG_DrawAccboard();
 }
 
 
@@ -2942,9 +3378,6 @@ Perform all drawing needed to completely fill the screen
 =====================
 */
 void CG_DrawActive( stereoFrame_t stereoView ) {
-	float		separation;
-	vec3_t		baseOrg;
-
 	// optionally draw the info screen instead
 	if ( !cg.snap ) {
 		CG_DrawInformation();
@@ -2958,41 +3391,17 @@ void CG_DrawActive( stereoFrame_t stereoView ) {
 		return;
 	}
 
-	switch ( stereoView ) {
-	case STEREO_CENTER:
-		separation = 0;
-		break;
-	case STEREO_LEFT:
-		separation = -cg_stereoSeparation.value / 2;
-		break;
-	case STEREO_RIGHT:
-		separation = cg_stereoSeparation.value / 2;
-		break;
-	default:
-		separation = 0;
-		CG_Error( "CG_DrawActive: Undefined stereoView" );
-	}
-
-
 	// clear around the rendered view if sized down
 	CG_TileClear();
 
-	// offset vieworg appropriately if we're doing stereo separation
-	VectorCopy( cg.refdef.vieworg, baseOrg );
-	if ( separation != 0 ) {
-		VectorMA( cg.refdef.vieworg, -separation, cg.refdef.viewaxis[1], cg.refdef.vieworg );
-	}
+	if(stereoView != STEREO_CENTER)
+		CG_DrawCrosshair3D();
 
 	// draw 3D view
 	trap_R_RenderScene( &cg.refdef );
 
-	// restore original viewpoint if running stereo
-	if ( separation != 0 ) {
-		VectorCopy( baseOrg, cg.refdef.vieworg );
-	}
-
 	// draw status bar and other floating elements
- 	CG_Draw2D();
+ 	CG_Draw2D(stereoView);
 }
 
 
