@@ -2,20 +2,21 @@
 ===========================================================================
 Copyright (C) 1999-2005 Id Software, Inc.
 
-This file is part of Quake III Arena source code.
+This file is part of Open Arena source code.
+Portions copied from Tremulous under GPL version 2 including any later version.
 
-Quake III Arena source code is free software; you can redistribute it
+Open Arena source code is free software; you can redistribute it
 and/or modify it under the terms of the GNU General Public License as
 published by the Free Software Foundation; either version 2 of the License,
 or (at your option) any later version.
 
-Quake III Arena source code is distributed in the hope that it will be
+Open Arena source code is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Quake III Arena source code; if not, write to the Free Software
+along with Open Arena source code; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 ===========================================================================
 */
@@ -654,7 +655,6 @@ Only in CTF games
 /* sounds */ ""
 	},
 
-#ifdef MISSIONPACK
 /*QUAKED holdable_kamikaze (.3 .3 1) (-16 -16 -16) (16 16 16) suspended
 */
 	{
@@ -818,6 +818,7 @@ Only in CTF games
 /* sounds */ ""
 	},
 
+        
 	/*QUAKED team_CTF_neutralflag (0 0 1) (-16 -16 -16) (16 16 16)
 Only in One Flag CTF games
 */
@@ -914,7 +915,7 @@ Only in One Flag CTF games
 /* precache */ "",
 /* sounds */ "sound/weapons/vulcan/wvulwind.wav"
 	},
-#endif
+//#endif
 
 /*QUAKED team_DD_point
 Only in DD games
@@ -924,7 +925,7 @@ Only in DD games
 		NULL,
         { "models/dpoints/a_blue.md3",
 		NULL, NULL, NULL },
-/* icon */		"icons/icona_blu",
+/* icon */		"icons/icona_blue",
 /* pickup */	"Point A (Blue)",
 		0,
 		IT_TEAM,
@@ -941,7 +942,7 @@ Only in DD games
 		NULL,
         { "models/dpoints/b_blue.md3",
 		NULL, NULL, NULL },
-/* icon */		"icons/iconb_blu",
+/* icon */		"icons/iconb_blue",
 /* pickup */	"Point B (Blue)",
 		0,
 		IT_TEAM,
@@ -1020,15 +1021,16 @@ Only in DD games
 
 //Now things for standard domination:
 
+
 /*QUAKED 
 Only in Domination games
 */
 	{
 		"team_dom_pointWhite",
 		NULL,
-        { "models/dpoints/a_white.md3",
+        { "models/flags/n_flag.md3",
 		NULL, NULL, NULL },
-/* icon */		"icons/icona_white",
+/* icon */		"icons/iconf_neutral1",
 /* pickup */	"Neutral domination point",
 		0,
 		IT_TEAM,
@@ -1043,9 +1045,9 @@ Only in Domination games
 	{
 		"team_dom_pointRed",
 		NULL,
-        { "models/dpoints/a_red.md3",
+        { "models/flags/r_flag.md3",
 		NULL, NULL, NULL },
-/* icon */		"icons/icona_red",
+/* icon */		"icons/iconf_red1",
 /* pickup */	"Red domination point",
 		0,
 		IT_TEAM,
@@ -1060,9 +1062,9 @@ Only in Domination games
 	{
 		"team_dom_pointBlue",
 		NULL,
-        { "models/dpoints/a_blue.md3",
+        { "models/flags/b_flag.md3",
 		NULL, NULL, NULL },
-/* icon */		"icons/icona_blue",
+/* icon */		"icons/iconf_blu1",
 /* pickup */	"Blue domination point",
 		0,
 		IT_TEAM,
@@ -1193,9 +1195,7 @@ This needs to be the same for client side prediction and server use.
 */
 qboolean BG_CanItemBeGrabbed( int gametype, const entityState_t *ent, const playerState_t *ps ) {
 	gitem_t	*item;
-#ifdef MISSIONPACK
 	int		upperBound;
-#endif
 
 	if ( ent->modelindex < 1 || ent->modelindex >= bg_numItems ) {
 		Com_Error( ERR_DROP, "BG_CanItemBeGrabbed: index out of range" );
@@ -1214,7 +1214,6 @@ qboolean BG_CanItemBeGrabbed( int gametype, const entityState_t *ent, const play
 		return qtrue;
 
 	case IT_ARMOR:
-#ifdef MISSIONPACK
 		if( bg_itemlist[ps->stats[STAT_PERSISTANT_POWERUP]].giTag == PW_SCOUT ) {
 			return qfalse;
 		}
@@ -1230,22 +1229,15 @@ qboolean BG_CanItemBeGrabbed( int gametype, const entityState_t *ent, const play
 		if ( ps->stats[STAT_ARMOR] >= upperBound ) {
 			return qfalse;
 		}
-#else
-		if ( ps->stats[STAT_ARMOR] >= ps->stats[STAT_MAX_HEALTH] * 2 ) {
-			return qfalse;
-		}
-#endif
 		return qtrue;
 
 	case IT_HEALTH:
 		// small and mega healths will go over the max, otherwise
 		// don't pick up if already at max
-#ifdef MISSIONPACK
 		if( bg_itemlist[ps->stats[STAT_PERSISTANT_POWERUP]].giTag == PW_GUARD ) {
 			upperBound = ps->stats[STAT_MAX_HEALTH];
 		}
 		else
-#endif
 		if ( item->quantity == 5 || item->quantity == 100 ) {
 			if ( ps->stats[STAT_HEALTH] >= ps->stats[STAT_MAX_HEALTH] * 2 ) {
 				return qfalse;
@@ -1261,7 +1253,6 @@ qboolean BG_CanItemBeGrabbed( int gametype, const entityState_t *ent, const play
 	case IT_POWERUP:
 		return qtrue;	// powerups are always picked up
 
-#ifdef MISSIONPACK
 	case IT_PERSISTANT_POWERUP:
 
 		//In Double D we don't want persistant Powerups (or maybe, can be discussed)
@@ -1282,10 +1273,8 @@ qboolean BG_CanItemBeGrabbed( int gametype, const entityState_t *ent, const play
 		}
 
 		return qtrue;
-#endif
 
-	case IT_TEAM: // team items, such as flags
-#ifdef MISSIONPACK		
+	case IT_TEAM: // team items, such as flags	
 		if( gametype == GT_1FCTF ) {
 			// neutral flag can always be picked up
 			if( item->giTag == PW_NEUTRALFLAG ) {
@@ -1301,7 +1290,6 @@ qboolean BG_CanItemBeGrabbed( int gametype, const entityState_t *ent, const play
 				}
 			}
 		}
-#endif
 		if( gametype == GT_CTF || gametype == GT_CTF_ELIMINATION) {
 			// ent->modelindex2 is non-zero on items if they are dropped
 			// we need to know this because we can pick up our dropped flag (and return it)
@@ -1337,11 +1325,9 @@ qboolean BG_CanItemBeGrabbed( int gametype, const entityState_t *ent, const play
 			}
 		}
 
-#ifdef MISSIONPACK
 		if( gametype == GT_HARVESTER ) {
 			return qtrue;
 		}
-#endif
 		return qfalse;
 
 	case IT_HOLDABLE:
@@ -1539,7 +1525,7 @@ char *eventnames[] = {
 	"EV_GIB_PLAYER",			// gib a previously living player
 	"EV_SCOREPLUM",			// score plum
 
-//#ifdef MISSIONPACK
+//Not all of these are used in baseoa but we keep them to gurantie event numbers between version
 	"EV_PROXIMITY_MINE_STICK",
 	"EV_PROXIMITY_MINE_TRIGGER",
 	"EV_KAMIKAZE",			// kamikaze explodes
@@ -1547,7 +1533,7 @@ char *eventnames[] = {
 	"EV_INVUL_IMPACT",		// invulnerability sphere impact
 	"EV_JUICED",				// invulnerability juiced effect
 	"EV_LIGHTNINGBOLT",		// lightning bolt bounced of invulnerability sphere
-//#endif
+
 
 	"EV_DEBUG_LINE",
 	"EV_STOPLOOPINGSOUND",
@@ -1780,3 +1766,22 @@ void BG_PlayerStateToEntityStateExtraPolate( playerState_t *ps, entityState_t *s
 	s->loopSound = ps->loopSound;
 	s->generic1 = ps->generic1;
 }
+
+/*
+============
+BG_TeamName
+KK-OAX Copied from Tremulous
+============
+*/
+char *BG_TeamName( team_t team )
+{
+  if( team == TEAM_NONE )
+    return "spectator";
+  if( team == TEAM_RED )
+    return "Red";
+  if( team == TEAM_BLUE )
+    return "Blue";
+  if( team == TEAM_FREE )
+    return "Free For All";
+  return "<team>";
+}
