@@ -239,7 +239,8 @@ Handles user intended acceleration
 ==============
 */
 static void PM_Accelerate( vec3_t wishdir, float wishspeed, float accel ) {
-#if 1
+if(! (pm->pmove_flags & DF_NO_BUNNY) ) {
+//#if 1
 
 	// q2 style
 	int			i;
@@ -258,7 +259,8 @@ static void PM_Accelerate( vec3_t wishdir, float wishspeed, float accel ) {
 	for (i=0 ; i<3 ; i++) {
 		pm->ps->velocity[i] += accelspeed*wishdir[i];	
 	}
-#else
+} else {
+        //#else
 	// proper way (avoids strafe jump maxspeed bug), but feels bad
 	vec3_t		wishVelocity;
 	vec3_t		pushDir;
@@ -276,7 +278,7 @@ static void PM_Accelerate( vec3_t wishdir, float wishspeed, float accel ) {
 
 	VectorMA( pm->ps->velocity, canPush, pushDir, pm->ps->velocity );
 }
-#endif
+//#endif
 }
 
 
@@ -434,7 +436,7 @@ static qboolean	PM_CheckWaterJump( void ) {
 
 	spot[2] += 16;
 	cont = pm->pointcontents (spot, pm->ps->clientNum );
-	if ( cont ) {
+	if ( cont & (CONTENTS_SOLID|CONTENTS_PLAYERCLIP|CONTENTS_BODY) ) {
 		return qfalse;
 	}
 
@@ -543,7 +545,6 @@ static void PM_WaterMove( void ) {
 	PM_SlideMove( qfalse );
 }
 
-#ifdef MISSIONPACK
 /*
 ===================
 PM_InvulnerabilityMove
@@ -557,7 +558,6 @@ static void PM_InvulnerabilityMove( void ) {
 	pm->cmd.upmove = 0;
 	VectorClear(pm->ps->velocity);
 }
-#endif
 
 /*
 ===================
@@ -1488,10 +1488,16 @@ static void PM_BeginWeaponChange( int weapon ) {
 		return;
 	}
 
-	PM_AddEvent( EV_CHANGE_WEAPON );
-	pm->ps->weaponstate = WEAPON_DROPPING;
-	pm->ps->weaponTime += 200;
-	PM_StartTorsoAnim( TORSO_DROP );
+        if(pm->pmove_flags & DF_INSTANT_WEAPON_CHANGE)
+        {
+                pm->ps->weaponstate = WEAPON_DROPPING;
+        } else
+        {
+            PM_AddEvent( EV_CHANGE_WEAPON );
+            pm->ps->weaponstate = WEAPON_DROPPING;
+            pm->ps->weaponTime += 200;
+            PM_StartTorsoAnim( TORSO_DROP );
+        }
 }
 
 
@@ -1514,8 +1520,11 @@ static void PM_FinishWeaponChange( void ) {
 
 	pm->ps->weapon = weapon;
 	pm->ps->weaponstate = WEAPON_RAISING;
-	pm->ps->weaponTime += 250;
-	PM_StartTorsoAnim( TORSO_RAISE );
+        if(! (pm->pmove_flags & DF_INSTANT_WEAPON_CHANGE))
+        {
+                pm->ps->weaponTime += 250;
+                PM_StartTorsoAnim( TORSO_RAISE );
+        }
 }
 
 
@@ -1687,7 +1696,6 @@ static void PM_Weapon( void ) {
 	case WP_GRAPPLING_HOOK:
 		addTime = 400;
 		break;
-#ifdef MISSIONPACK
 	case WP_NAILGUN:
 		addTime = 1000;
 		break;
@@ -1697,10 +1705,8 @@ static void PM_Weapon( void ) {
 	case WP_CHAINGUN:
 		addTime = 30;
 		break;
-#endif
 	}
 
-#ifdef MISSIONPACK
 	if( bg_itemlist[pm->ps->stats[STAT_PERSISTANT_POWERUP]].giTag == PW_SCOUT ) {
 		addTime /= 1.5;
 	}
@@ -1709,7 +1715,6 @@ static void PM_Weapon( void ) {
 		addTime /= 1.3;
   }
   else
-#endif
 	if ( pm->ps->powerups[PW_HASTE] ) {
 		addTime /= 1.3;
 	}
@@ -1730,7 +1735,6 @@ static void PM_Animate( void ) {
 			pm->ps->torsoTimer = TIMER_GESTURE;
 			PM_AddEvent( EV_TAUNT );
 		}
-#ifdef MISSIONPACK
 	} else if ( pm->cmd.buttons & BUTTON_GETFLAG ) {
 		if ( pm->ps->torsoTimer == 0 ) {
 			PM_StartTorsoAnim( TORSO_GETFLAG );
@@ -1761,7 +1765,6 @@ static void PM_Animate( void ) {
 			PM_StartTorsoAnim( TORSO_NEGATIVE );
 			pm->ps->torsoTimer = 600;	//TIMER_GESTURE;
 		}
-#endif
 	}
 }
 
@@ -1875,7 +1878,7 @@ void PmoveSingle (pmove_t *pmove) {
 	}
 
 	// set the firing flag for continuous beam weapons
-	if ( !(pm->ps->pm_flags & PMF_RESPAWNED) && pm->ps->pm_type != PM_INTERMISSION
+	if ( !(pm->ps->pm_flags & PMF_RESPAWNED) && pm->ps->pm_type != PM_INTERMISSION && pm->ps->pm_type != PM_NOCLIP
 		&& ( pm->cmd.buttons & BUTTON_ATTACK ) && pm->ps->ammo[ pm->ps->weapon ] ) {
 		pm->ps->eFlags |= EF_FIRING;
 	} else {
@@ -1980,11 +1983,9 @@ void PmoveSingle (pmove_t *pmove) {
 
 	PM_DropTimers();
 
-#ifdef MISSIONPACK
 	if ( pm->ps->powerups[PW_INVULNERABILITY] ) {
 		PM_InvulnerabilityMove();
 	} else
-#endif
 	if ( pm->ps->powerups[PW_FLIGHT] ) {
 		// flight powerup doesn't allow jump and has different friction
 		PM_FlyMove();
@@ -2025,7 +2026,9 @@ void PmoveSingle (pmove_t *pmove) {
 	PM_WaterEvents();
 
 	// snap some parts of playerstate to save network bandwidth
-	trap_SnapVector( pm->ps->velocity );
+        //But only if pmove_float is not enabled
+        if(!(pm->pmove_float))
+            trap_SnapVector( pm->ps->velocity );
 }
 
 
