@@ -55,9 +55,13 @@ void SP_info_player_start(gentity_t *ent) {
 	SP_info_player_deathmatch( ent );
 }
 
-//One for Double_D
+//Three for Double_D
 void SP_info_player_dd(gentity_t *ent) {
 }
+void SP_info_player_dd_red(gentity_t *ent) {
+}
+void SP_info_player_dd_blue(gentity_t *ent) {
+}
 
 //One for Standard Domination, not really a player spawn point
 void SP_domination_point(gentity_t *ent) {
@@ -247,9 +251,9 @@ Chooses a player start, deathmatch start, etc
 ============
 */
 gentity_t *SelectSpawnPoint ( vec3_t avoidPoint, vec3_t origin, vec3_t angles ) {
-	return SelectRandomFurthestSpawnPoint( avoidPoint, origin, angles );
+	//return SelectRandomFurthestSpawnPoint( avoidPoint, origin, angles );
 
-	/*
+	
 	gentity_t	*spot;
 	gentity_t	*nearestSpot;
 
@@ -275,7 +279,6 @@ gentity_t *SelectSpawnPoint ( vec3_t avoidPoint, vec3_t origin, vec3_t angles )
 	VectorCopy (spot->s.angles, angles);
 
 	return spot;
-	*/
 }
 
 /*
@@ -369,6 +372,8 @@ After sitting around for five seconds, fall into the ground and dissapear
 */
 void BodySink( gentity_t *ent ) {
 	if ( level.time - ent->timestamp > 6500 ) {
+
+
 		// the body ques are never actually freed, they are just unlinked
 		trap_UnlinkEntity( ent );
 		ent->physicsObject = qfalse;
@@ -387,10 +392,8 @@ just like the existing corpse to leave behind.
 =============
 */
 void CopyToBodyQue( gentity_t *ent ) {
-#ifdef MISSIONPACK
 	gentity_t	*e;
 	int i;
-#endif
 	gentity_t		*body;
 	int			contents;
 
@@ -398,20 +401,23 @@ void CopyToBodyQue( gentity_t *ent ) {
 
 	// if client is in a nodrop area, don't leave the body
 	contents = trap_PointContents( ent->s.origin, -1 );
-	if ( contents & CONTENTS_NODROP ) {
-		return;
+	if ( (contents & CONTENTS_NODROP) && !(ent->s.eFlags & EF_KAMIKAZE) ) { //the check for kamikaze is a workaround for ctf4ish
+            return;
 	}
 
 	// grab a body que and cycle to the next one
 	body = level.bodyQue[ level.bodyQueIndex ];
 	level.bodyQueIndex = (level.bodyQueIndex + 1) % BODY_QUEUE_SIZE;
 
-	trap_UnlinkEntity (body);
+        //Check if the next body has the kamikaze, in that case skip it.
+        for(i=0;(level.bodyQue[ level.bodyQueIndex ]->s.eFlags & EF_KAMIKAZE) && (i<10);i++) {
+            level.bodyQueIndex = (level.bodyQueIndex + 1) % BODY_QUEUE_SIZE;
+        }
 
 	body->s = ent->s;
 	body->s.eFlags = EF_DEAD;		// clear EF_TALK, etc
-#ifdef MISSIONPACK
 	if ( ent->s.eFlags & EF_KAMIKAZE ) {
+                ent->s.eFlags &= ~EF_KAMIKAZE;
 		body->s.eFlags |= EF_KAMIKAZE;
 
 		// check if there is a kamikaze timer around for this owner
@@ -427,7 +433,6 @@ void CopyToBodyQue( gentity_t *ent ) {
 			break;
 		}
 	}
-#endif
 	body->s.powerups = 0;	// clear powerups
 	body->s.loopSound = 0;	// clear lava burning
 	body->s.number = body - g_entities;
@@ -516,14 +521,17 @@ void SetClientViewAngle( gentity_t *ent, vec3_t angle ) {
 respawn
 ================
 */
-void respawn( gentity_t *ent ) {
+void ClientRespawn( gentity_t *ent ) {
 	gentity_t	*tent;
 
 	if((g_gametype.integer!=GT_ELIMINATION && g_gametype.integer!=GT_CTF_ELIMINATION && g_gametype.integer !=GT_LMS) && !ent->client->isEliminated)
 	{
 		ent->client->isEliminated = qtrue; //must not be true in warmup
 		//Tried moving CopyToBodyQue
-	}
+	} else {
+                //Must always be false in other gametypes
+                ent->client->isEliminated = qfalse;
+        }
         CopyToBodyQue (ent); //Unlinks ent
 
 	if(g_gametype.integer==GT_LMS) {
@@ -541,7 +549,7 @@ void respawn( gentity_t *ent ) {
                                 //Sago: This is really bad
                                 //TODO: Try not to make people spectators here
 				ent->client->sess.spectatorState = PM_SPECTATOR;
-                                //We have to force spawn imidiantly to precent lag.
+                                //We have to force spawn imidiantly to prevent lag.
                                 ClientSpawn(ent);
 			}
 			return;
@@ -574,17 +582,85 @@ void respawnRound( gentity_t *ent ) {
 	//	ent->client->isEliminated  = qtrue;
 		//CopyToBodyQue (ent);
 	//}
+        
 
 	//if(g_gametype.integer==GT_ELIMINATION && ent->client->ps.pm_type == PM_SPECTATOR && ent->client->ps.stats[STAT_HEALTH] > 0)
 	//	return;
-		ClientSpawn(ent);
+        if(ent->client->hook)
+                Weapon_HookFree(ent->client->hook);
 
-		// add a teleportation effect
-		if(g_gametype.integer!=GT_ELIMINATION && g_gametype.integer!=GT_CTF_ELIMINATION && g_gametype.integer!=GT_LMS)
-		{	
-			tent = G_TempEntity( ent->client->ps.origin, EV_PLAYER_TELEPORT_IN );
-			tent->s.clientNum = ent->s.clientNum;
+        trap_UnlinkEntity (ent);
+
+	ClientSpawn(ent);
+
+        // add a teleportation effect
+        if(g_gametype.integer!=GT_ELIMINATION && g_gametype.integer!=GT_CTF_ELIMINATION && g_gametype.integer!=GT_LMS)
+        {
+                tent = G_TempEntity( ent->client->ps.origin, EV_PLAYER_TELEPORT_IN );
+                tent->s.clientNum = ent->s.clientNum;
+        }
+}
+
+/*
+================
+TeamCvarSet
+
+Sets the red and blue team client number cvars.
+================
+ */
+void TeamCvarSet( void )
+{
+    int i;
+    qboolean redChanged = qfalse;
+    qboolean blueChanged = qfalse;
+    qboolean first = qtrue;
+    char* temp = NULL;
+
+    for ( i = 0 ; i < level.maxclients ; i++ ) {
+		if ( level.clients[i].pers.connected == CON_DISCONNECTED ) {
+			continue;
 		}
+		if ( level.clients[i].sess.sessionTeam == TEAM_RED ) {
+                    if(first) {
+                        temp = va("%i",i);
+                        first = qfalse;
+                    }
+                    else
+                        temp = va("%s,%i",temp,i);
+		}
+	}
+
+    if(Q_stricmp(g_redTeamClientNumbers.string,temp))
+        redChanged = qtrue;
+    trap_Cvar_Set("g_redTeamClientNumbers",temp); //Set it right
+    first= qtrue;
+
+    for ( i = 0 ; i < level.maxclients ; i++ ) {
+		if ( level.clients[i].pers.connected == CON_DISCONNECTED ) {
+			continue;
+		}
+		if ( level.clients[i].sess.sessionTeam == TEAM_BLUE ) {
+                    if(first) {
+                        temp = va("%i",i);
+                        first = qfalse;
+                    }
+                    else
+                        temp = va("%s,%i",temp,i);
+		}
+	}
+    if(Q_stricmp(g_blueTeamClientNumbers.string,temp))
+        blueChanged = qtrue;
+    trap_Cvar_Set("g_blueTeamClientNumbers",temp);
+
+    //Note: We need to force update of the cvar or SendYourTeamMessage will send the old cvar value!
+    if(redChanged) {
+        trap_Cvar_Update(&g_redTeamClientNumbers); //Force update of CVAR
+        SendYourTeamMessageToTeam(TEAM_RED);
+    }
+    if(blueChanged) {
+        trap_Cvar_Update(&g_blueTeamClientNumbers);
+        SendYourTeamMessageToTeam(TEAM_BLUE); //Force update of CVAR
+    }
 }
 
 /*
@@ -605,6 +681,11 @@ team_t TeamCount( int ignoreClientNum, int team ) {
 		if ( level.clients[i].pers.connected == CON_DISCONNECTED ) {
 			continue;
 		}
+
+                if ( level.clients[i].pers.connected == CON_CONNECTING) {
+                        continue;
+                }
+
 		if ( level.clients[i].sess.sessionTeam == team ) {
 			count++;
 		}
@@ -632,6 +713,10 @@ team_t TeamLivingCount( int ignoreClientNum, int team ) {
 		if ( level.clients[i].pers.connected == CON_DISCONNECTED ) {
 			continue;
 		}
+
+                if ( level.clients[i].pers.connected == CON_CONNECTING) {
+                        continue;
+                }
 		//crash if g_gametype.integer is used here, why?
 		if ( level.clients[i].sess.sessionTeam == team && (level.clients[i].ps.stats[STAT_HEALTH]>0 || LMS) && !(level.clients[i].isEliminated)) {
 			count++;
@@ -660,6 +745,11 @@ team_t TeamHealthCount(int ignoreClientNum, int team ) {
 		if ( level.clients[i].pers.connected == CON_DISCONNECTED ) {
 			continue;
 		}
+
+                if ( level.clients[i].pers.connected == CON_CONNECTING) {
+                        continue;
+                }
+
 		//only count clients with positive health
 		if ( level.clients[i].sess.sessionTeam == team && (level.clients[i].ps.stats[STAT_HEALTH]>0)&& !(level.clients[i].isEliminated)) {
 			count+=level.clients[i].ps.stats[STAT_HEALTH];
@@ -688,6 +778,10 @@ void RespawnAll(void)
 			continue;
 		}
 
+                if ( level.clients[i].pers.connected == CON_CONNECTING) {
+                        continue;
+                }
+
 		if ( level.clients[i].sess.sessionTeam == TEAM_SPECTATOR ) {
 			continue;
 		}
@@ -717,6 +811,9 @@ void RespawnDead(void)
 		if ( level.clients[i].pers.connected == CON_DISCONNECTED ) {
 			continue;
 		}
+                if ( level.clients[i].pers.connected == CON_CONNECTING) {
+                        continue;
+                }
                 client = g_entities + i;
                 client->client->pers.livesLeft = g_lms_lives.integer-1;
 		if ( level.clients[i].isEliminated == qfalse ){
@@ -750,6 +847,9 @@ void DisableWeapons(void)
 		if ( level.clients[i].pers.connected == CON_DISCONNECTED ) {
 			continue;
 		}
+                if ( level.clients[i].pers.connected == CON_CONNECTING) {
+                        continue;
+                }
 
 		if ( level.clients[i].sess.sessionTeam == TEAM_SPECTATOR ) {
 			continue;
@@ -757,6 +857,7 @@ void DisableWeapons(void)
 		client = g_entities + i;
 		client->client->ps.pm_flags |= PMF_ELIMWARMUP;
 	}
+        ProximityMine_RemoveAll(); //Remove all the prox mines
 	return;
 }
 
@@ -814,7 +915,7 @@ void LMSpoint(void)
 			continue;
 		}
 
-		if ( level.clients[i].isEliminated == qtrue ){
+		if ( level.clients[i].isEliminated ){
 			continue;
 		}
 		
@@ -827,6 +928,8 @@ void LMSpoint(void)
 		*/
 	
 		client->client->ps.persistant[PERS_SCORE] += 1;
+                        G_LogPrintf("PlayerScore: %i %i: %s now has %d points\n",
+		i, client->client->ps.persistant[PERS_SCORE], client->client->pers.netname, client->client->ps.persistant[PERS_SCORE] );
 	}
 	
 	CalculateRanks();
@@ -868,18 +971,27 @@ team_t PickTeam( int ignoreClientNum ) {
 
 	counts[TEAM_BLUE] = TeamCount( ignoreClientNum, TEAM_BLUE );
 	counts[TEAM_RED] = TeamCount( ignoreClientNum, TEAM_RED );
-
-	if ( counts[TEAM_BLUE] > counts[TEAM_RED] ) {
+    
+    //KK-OAX Both Teams locked...forget about it, print an error message, keep as spec
+    if ( level.RedTeamLocked && level.BlueTeamLocked ) {
+        G_Printf( "Both teams have been locked by the Admin! \n" );
+        return TEAM_NONE;
+    }	
+	if ( ( counts[TEAM_BLUE] > counts[TEAM_RED] ) && ( !level.RedTeamLocked ) ) {
 		return TEAM_RED;
 	}
-	if ( counts[TEAM_RED] > counts[TEAM_BLUE] ) {
+	if ( ( counts[TEAM_RED] > counts[TEAM_BLUE] ) && ( !level.BlueTeamLocked ) ) {
 		return TEAM_BLUE;
 	}
 	// equal team count, so join the team with the lowest score
-	if ( level.teamScores[TEAM_BLUE] > level.teamScores[TEAM_RED] ) {
+	if ( ( level.teamScores[TEAM_BLUE] > level.teamScores[TEAM_RED] ) && ( !level.RedTeamLocked ) ) {
 		return TEAM_RED;
 	}
-	return TEAM_BLUE;
+	if ( ( level.teamScores[TEAM_RED] > level.teamScores[TEAM_BLUE] ) && ( !level.BlueTeamLocked ) ) {  
+	    return TEAM_BLUE;
+    }
+    //KK-OAX Force Team Blue?
+    return TEAM_BLUE;
 }
 
 /*
@@ -893,7 +1005,7 @@ Forces a client's skin (for teamplay)
 static void ForceClientSkin( gclient_t *client, char *model, const char *skin ) {
 	char *p;
 
-	if ((p = Q_strrchr(model, '/')) != 0) {
+	if ((p = strrchr(model, '/')) != 0) {
 		*p = 0;
 	}
 
@@ -907,88 +1019,73 @@ static void ForceClientSkin( gclient_t *client, char *model, const char *skin )
 ClientCheckName
 ============
 */
-static void ClientCleanName( const char *in, char *out, int outSize ) {
-	int		len, colorlessLen;
-	char	ch;
-	char	*p;
-	int		spaces;
+static void ClientCleanName(const char *in, char *out, int outSize, int clientNum)
+{
+    int outpos = 0, colorlessLen = 0, spaces = 0, notblack=0;
+    qboolean black = qfalse;
 
-	//save room for trailing null byte
-	outSize--;
+    // discard leading spaces
+    for(; *in == ' '; in++);
 
-	len = 0;
-	colorlessLen = 0;
-	p = out;
-	*p = 0;
-	spaces = 0;
+    for(; *in && outpos < outSize - 1; in++)
+    {
+        out[outpos] = *in;
 
-	while( 1 ) {
-		ch = *in++;
-		if( !ch ) {
-			break;
-		}
+        if(*in == ' ')
+        {
+            // don't allow too many consecutive spaces
+            if(spaces > 2)
+                continue;
 
-		// don't allow leading spaces
-		if( colorlessLen == 0 && ch == ' ' ) {
-			continue;
-		}
+            spaces++;
+        }
+        else if(outpos > 0 && out[outpos - 1] == Q_COLOR_ESCAPE)
+        {
+            if(Q_IsColorString(&out[outpos - 1]))
+            {
+                colorlessLen--;
 
-		// check colors
-		if( ch == Q_COLOR_ESCAPE ) {
-			// solo trailing carat is not a color prefix
-			if( !*in ) {
-				break;
-			}
+                if(ColorIndex(*in) == 0)
+                {
+                    // Disallow color black in names to prevent players
+                    // from getting advantage playing in front of black backgrounds
+                    //outpos--;
+                    //continue;
+                    black = qtrue;
+                }
+                else
+                    black = qfalse;
+            }
+            else
+            {
+                spaces = 0;
+                colorlessLen++;
+            }
+        }
+        else
+        {
+            spaces = 0;
+            colorlessLen++;
+            if(!black && (Q_isalpha(*in) || (*in>='0' && *in<='9') ) )
+                notblack++;
+        }
 
-			// don't allow black in a name, period
-			if( ColorIndex(*in) == 0 ) {
-				in++;
-				continue;
-			}
+        outpos++;
+    }
 
-			// make sure room in dest for both chars
-			if( len > outSize - 2 ) {
-				break;
-			}
+    out[outpos] = '\0';
 
-			*out++ = ch;
-			*out++ = *in++;
-			len += 2;
-			continue;
-		}
+    //There was none not-black alphanum chars. Remove all colors
+    if(notblack<1)
+        Q_CleanStr(out);
 
-		// don't allow too many consecutive spaces
-		// don't count spaces in colorlessLen
-                if( ch == ' ' ) {
-			spaces++;
-			if( spaces > 3 ) {
-				continue;
-			}
-                        *out++ = ch;
-			len++;
-			continue;
-		}
-		else {
-			spaces = 0;
-		}
-
-		if( len > outSize - 1 ) {
-			break;
-		}
-
-		*out++ = ch;
-		colorlessLen++;
-		len++;
-	}
-	*out = 0;
-
-	// don't allow empty names
-	if( *p == 0 || colorlessLen == 0 ) {
-		Q_strncpyz( p, "UnnamedPlayer", outSize );
-	}
+    // don't allow empty names
+    if( *out == '\0' || colorlessLen == 0)
+        Q_strncpyz(out, va("Nameless%i",clientNum), outSize );
 }
 
 
+
 /*
 ===========
 ClientUserInfoChanged
@@ -1007,6 +1104,10 @@ void ClientUserinfoChanged( int clientNum ) {
 	char	model[MAX_QPATH];
 	char	headModel[MAX_QPATH];
 	char	oldname[MAX_STRING_CHARS];
+	//KK-OAX
+	char        err[MAX_STRING_CHARS];
+	qboolean    revertName = qfalse;
+	
 	gclient_t	*client;
 	char	c1[MAX_INFO_STRING];
 	char	c2[MAX_INFO_STRING];
@@ -1076,8 +1177,60 @@ void ClientUserinfoChanged( int clientNum ) {
 	// set name
 	Q_strncpyz ( oldname, client->pers.netname, sizeof( oldname ) );
 	s = Info_ValueForKey (userinfo, "name");
-	ClientCleanName( s, client->pers.netname, sizeof(client->pers.netname) );
+	ClientCleanName( s, client->pers.netname, sizeof(client->pers.netname), clientNum );
 
+    //KK-OAPub Added From Tremulous-Control Name Changes
+    if( strcmp( oldname, client->pers.netname ) )
+    {
+        if( client->pers.nameChangeTime &&
+            ( level.time - client->pers.nameChangeTime )
+            <= ( g_minNameChangePeriod.value * 1000 ) )
+        {
+            trap_SendServerCommand( ent - g_entities, va(
+            "print \"Name change spam protection (g_minNameChangePeriod = %d)\n\"",
+            g_minNameChangePeriod.integer ) );
+            revertName = qtrue;
+        }
+        else if( g_maxNameChanges.integer > 0
+            && client->pers.nameChanges >= g_maxNameChanges.integer  )
+        {
+            trap_SendServerCommand( ent - g_entities, va(
+                "print \"Maximum name changes reached (g_maxNameChanges = %d)\n\"",
+                g_maxNameChanges.integer ) );
+            revertName = qtrue;
+        }
+        else if( client->pers.muted )
+        {
+            trap_SendServerCommand( ent - g_entities,
+                "print \"You cannot change your name while you are muted\n\"" );
+            revertName = qtrue;
+        }
+        else if( !G_admin_name_check( ent, client->pers.netname, err, sizeof( err ) ) )
+        {
+            trap_SendServerCommand( ent - g_entities, va( "print \"%s\n\"", err ) );
+            revertName = qtrue;
+        }
+
+        //Never revert a bots name... just to bad if it hapens... but the bot will always be expendeble :-)
+        if (ent->r.svFlags & SVF_BOT)
+            revertName = qfalse;
+
+        if( revertName )
+        {
+            Q_strncpyz( client->pers.netname, *oldname ? oldname : "UnnamedPlayer",
+                sizeof( client->pers.netname ) );
+            Info_SetValueForKey( userinfo, "name", oldname );
+            trap_SetUserinfo( clientNum, userinfo );
+        }
+        else
+        {
+            if( client->pers.connected == CON_CONNECTED )
+            {
+                client->pers.nameChangeTime = level.time;
+                client->pers.nameChanges++;
+            }
+        }
+    }
 	// N_G: this condition makes no sense to me and I'm not going to
 	// try finding out what it means, I've added parentheses according to
 	// evaluation rules of the original code so grab a
@@ -1101,7 +1254,6 @@ void ClientUserinfoChanged( int clientNum ) {
 	}
 
 	// set max health
-#ifdef MISSIONPACK
 	if (client->ps.powerups[PW_GUARD]) {
 		client->pers.maxHealth = 200;
 	} else {
@@ -1111,13 +1263,6 @@ void ClientUserinfoChanged( int clientNum ) {
 			client->pers.maxHealth = 100;
 		}
 	}
-#else
-	health = atoi( Info_ValueForKey( userinfo, "handicap" ) );
-	client->pers.maxHealth = health;
-	if ( client->pers.maxHealth < 1 || client->pers.maxHealth > 100 ) {
-		client->pers.maxHealth = 100;
-	}
-#endif
 	client->ps.stats[STAT_MAX_HEALTH] = client->pers.maxHealth;
 
 	// set model
@@ -1140,13 +1285,15 @@ void ClientUserinfoChanged( int clientNum ) {
 			// pick the team with the least number of players
 			team = PickTeam( clientNum );
 		}
+                client->sess.sessionTeam = team;
 	}
 	else {
 		team = client->sess.sessionTeam;
 	}
 
 /*	NOTE: all client side now
-
+Sago: I am not happy with this exception
+ 
 	// team
 	switch( team ) {
 	case TEAM_RED:
@@ -1166,7 +1313,6 @@ void ClientUserinfoChanged( int clientNum ) {
 	}
 */
 
-#ifdef MISSIONPACK
 	if (g_gametype.integer >= GT_TEAM && g_ffa_gt!=1) {
 		client->pers.teamInfo = qtrue;
 	} else {
@@ -1177,15 +1323,6 @@ void ClientUserinfoChanged( int clientNum ) {
 			client->pers.teamInfo = qfalse;
 		}
 	}
-#else
-	// teamInfo
-	s = Info_ValueForKey( userinfo, "teamoverlay" );
-	if ( ! *s || atoi( s ) != 0 ) {
-		client->pers.teamInfo = qtrue;
-	} else {
-		client->pers.teamInfo = qfalse;
-	}
-#endif
 	/*
 	s = Info_ValueForKey( userinfo, "cg_pmove_fixed" );
 	if ( !*s || atoi( s ) == 0 ) {
@@ -1202,8 +1339,27 @@ void ClientUserinfoChanged( int clientNum ) {
 	teamLeader = client->sess.teamLeader;
 
 	// colors
-	strcpy(c1, Info_ValueForKey( userinfo, "color1" ));
-	strcpy(c2, Info_ValueForKey( userinfo, "color2" ));
+        if( g_gametype.integer >= GT_TEAM && g_ffa_gt==0 && g_instantgib.integer) {
+            switch(team) {
+                case TEAM_RED:
+                    c1[0] = COLOR_BLUE;
+                    c2[0] = COLOR_BLUE;
+                    c1[1] = 0;
+                    c2[1] = 0;
+                    break;
+                case TEAM_BLUE:
+                    c1[0] = COLOR_RED;
+                    c2[0] = COLOR_RED;
+                    c1[1] = 0;
+                    c2[1] = 0;
+                    break;
+                default:
+                    break;
+            }
+        } else {
+            strcpy(c1, Info_ValueForKey( userinfo, "color1" ));
+            strcpy(c2, Info_ValueForKey( userinfo, "color2" ));
+        }
 
 	strcpy(redTeam, Info_ValueForKey( userinfo, "g_redteam" ));
 	strcpy(blueTeam, Info_ValueForKey( userinfo, "g_blueteam" ));
@@ -1224,7 +1380,7 @@ void ClientUserinfoChanged( int clientNum ) {
 	trap_SetConfigstring( CS_PLAYERS+clientNum, s );
 
 	// this is not the userinfo, more like the configstring actually
-	G_LogPrintf( "ClientUserinfoChanged: %i %s\n", clientNum, s );
+	G_LogPrintf( "ClientUserinfoChanged: %i %s\\id\\%s\n", clientNum, s, Info_ValueForKey(userinfo, "cl_guid") );
 }
 
 
@@ -1254,21 +1410,39 @@ char *ClientConnect( int clientNum, qboolean firstTime, qboolean isBot ) {
 	gclient_t	*client;
 	char		userinfo[MAX_INFO_STRING];
 	gentity_t	*ent;
-
+	char        reason[ MAX_STRING_CHARS ] = {""};
+	int         i;
+    
+    //KK-OAX I moved these up so userinfo could be assigned/used. 
 	ent = &g_entities[ clientNum ];
+	client = &level.clients[ clientNum ];
+	ent->client = client;
+	memset( client, 0, sizeof(*client) );
 
 	trap_GetUserinfo( clientNum, userinfo, sizeof( userinfo ) );
 
- 	// IP filtering
+ 	value = Info_ValueForKey( userinfo, "cl_guid" );
+ 	Q_strncpyz( client->pers.guid, value, sizeof( client->pers.guid ) );
+ 	
+
+ 	// IP filtering //KK-OAX Has this been obsoleted? 
  	// https://zerowing.idsoftware.com/bugzilla/show_bug.cgi?id=500
  	// recommanding PB based IP / GUID banning, the builtin system is pretty limited
  	// check to see if they are on the banned IP list
 	value = Info_ValueForKey (userinfo, "ip");
-	if ( G_FilterPacket( value ) ) {
+	Q_strncpyz( client->pers.ip, value, sizeof( client->pers.ip ) );
+	
+	if ( G_FilterPacket( value ) && !Q_stricmp(value,"localhost") ) {
+            G_Printf("Player with IP: %s is banned\n",value);
 		return "You are banned from this server.";
 	}
-
-  // we don't check password for bots and local client
+	
+    if( G_admin_ban_check( userinfo, reason, sizeof( reason ) ) ) {    
+ 	    return va( "%s", reason );
+ 	}
+ 	 
+  //KK-OAX
+  // we don't check GUID or password for bots and local client
   // NOTE: local client <-> "ip" "localhost"
   //   this means this client is not running in our current process
 	if ( !isBot && (strcmp(value, "localhost") != 0)) {
@@ -1278,15 +1452,31 @@ char *ClientConnect( int clientNum, qboolean firstTime, qboolean isBot ) {
 			strcmp( g_password.string, value) != 0) {
 			return "Invalid password";
 		}
+		for( i = 0; i < sizeof( client->pers.guid ) - 1 &&
+		    isxdigit( client->pers.guid[ i ] ); i++ );
+		if( i < sizeof( client->pers.guid ) - 1 )
+		    return "Invalid GUID";
+		    
+		for( i = 0; i < level.maxclients; i++ ) {
+		
+		    if( level.clients[ i ].pers.connected == CON_DISCONNECTED )
+		        continue;
+		        
+		    if( !Q_stricmp( client->pers.guid, level.clients[ i ].pers.guid ) ) {
+		        if( !G_ClientIsLagging( level.clients + i ) ) {
+		            trap_SendServerCommand( i, "cp \"Your GUID is not secure\"" );
+		                return "Duplicate GUID";
+		        }
+		        trap_DropClient( i, "Ghost" );
+		    }
+		}
+		    
 	}
 
-	// they can connect
-	ent->client = level.clients + clientNum;
-	client = ent->client;
-
-//	areabits = client->areabits;
-
-	memset( client, 0, sizeof(*client) );
+    //Check for local client
+    if( !strcmp( client->pers.ip, "localhost" ) )
+        client->pers.localClient = qtrue;
+        client->pers.adminLevel = G_admin_level( ent );
 
 	client->pers.connected = CON_CONNECTING;
 
@@ -1304,9 +1494,11 @@ char *ClientConnect( int clientNum, qboolean firstTime, qboolean isBot ) {
 		}
 	}
 
+	//KK-OAX Swapped these in order...seemed to help the connection process.
 	// get and distribute relevent paramters
-	G_LogPrintf( "ClientConnect: %i\n", clientNum );
 	ClientUserinfoChanged( clientNum );
+	G_LogPrintf( "ClientConnect: %i\n", clientNum );
+	
 
 	// don't do the "xxx connected" messages if they were caried over from previous level
 	if ( firstTime ) {
@@ -1335,11 +1527,39 @@ char *ClientConnect( int clientNum, qboolean firstTime, qboolean isBot ) {
 	else {
 		trap_SendServerCommand( clientNum, "print \"Full lag compensation is OFF!\n\"" );
 	}
-//unlagged - backward reconciliation #5
 
+//unlagged - backward reconciliation #5
+    G_admin_namelog_update( client, qfalse );
 	return NULL;
 }
 
+void motd (gentity_t *ent)
+{
+	char motd[1024];
+	fileHandle_t motdFile;
+	int motdLen;
+	int fileLen;
+
+	strcpy (motd, "cp \"");
+	fileLen = trap_FS_FOpenFile(g_motdfile.string, &motdFile, FS_READ);
+	if(motdFile)
+	{
+		char * p;
+
+		motdLen = strlen(motd);
+		if((motdLen + fileLen) > (sizeof(motd) - 2))
+			fileLen = (sizeof(motd) - 2 - motdLen);
+		trap_FS_Read(motd + motdLen, fileLen, motdFile);
+		motd[motdLen + fileLen] = '"';
+		motd[motdLen + fileLen + 1] = 0;
+		trap_FS_FCloseFile(motdFile);
+
+		while((p = strchr(motd, '\r'))) //Remove carrier return. 0x0D
+		memmove(p, p + 1, motdLen + fileLen - (p - motd));
+	}
+	trap_SendServerCommand(ent - g_entities, motd);
+}
+
 /*
 ===========
 ClientBegin
@@ -1352,8 +1572,12 @@ and on transition between teams, but doesn't happen on respawns
 void ClientBegin( int clientNum ) {
 	gentity_t	*ent;
 	gclient_t	*client;
-	gentity_t	*tent;
+	gentity_t       *tent;
 	int			flags;
+	int		countRed, countBlue, countFree;
+        char		userinfo[MAX_INFO_STRING];
+
+        trap_GetUserinfo( clientNum, userinfo, sizeof( userinfo ) );
 
 	ent = g_entities + clientNum;
 
@@ -1378,6 +1602,37 @@ void ClientBegin( int clientNum ) {
 		//trap_SendServerCommand( -1, va("print \"%s" S_COLOR_WHITE " will start dead\n\"", client->pers.netname) );
 	}
 
+	//player is a bot:
+	if( ent->r.svFlags & SVF_BOT )
+	{
+		if(!level.hadBots)
+		{
+			G_LogPrintf( "Info: There has been at least 1 bot now\n" );
+			level.hadBots = qtrue;
+		}
+	}
+
+	//Count smallest team
+	countFree = TeamCount(-1,TEAM_FREE);
+	countRed = TeamCount(-1,TEAM_RED);
+	countBlue = TeamCount(-1,TEAM_BLUE);
+	if(g_gametype.integer < GT_TEAM || g_ffa_gt)
+	{
+		if(countFree>level.teamSize)
+			level.teamSize=countFree;
+	}
+	else
+	if(countRed>countBlue)
+	{
+		if(countBlue>level.teamSize)
+			level.teamSize=countBlue;
+	}
+	else
+	{
+		if(countRed>level.teamSize)
+			level.teamSize=countRed;
+	}
+
 	// save eflags around this, because changing teams will
 	// cause this to happen with a valid entity, and we
 	// want to make sure the teleport bit is set right
@@ -1385,18 +1640,19 @@ void ClientBegin( int clientNum ) {
 	// world to the new position
 	flags = client->ps.eFlags;
 	memset( &client->ps, 0, sizeof( client->ps ) );
+        if( client->sess.sessionTeam != TEAM_SPECTATOR )
+            PlayerStore_restore(Info_ValueForKey(userinfo,"cl_guid"),&(client->ps));
 	client->ps.eFlags = flags;
 
 	// locate ent at a spawn point
 	ClientSpawn( ent );
 
-	// N_G: I'm really sure line 1333 is not what you meant
 	if( ( client->sess.sessionTeam != TEAM_SPECTATOR ) &&
 		( ( !( client->isEliminated ) /*&&
 		( ( !client->ps.pm_type ) == PM_SPECTATOR ) */ ) || //Sago: Yes, it made no sense 
-		( ( g_gametype.integer != GT_ELIMINATION ) &&
-		( g_gametype.integer != GT_CTF_ELIMINATION ) &&
-		( g_gametype.integer != GT_LMS ) ) ) ) {
+		( ( g_gametype.integer != GT_ELIMINATION || level.intermissiontime) &&
+		( g_gametype.integer != GT_CTF_ELIMINATION || level.intermissiontime) &&
+		( g_gametype.integer != GT_LMS || level.intermissiontime ) ) ) ) {
 		// send event
 		tent = G_TempEntity( ent->client->ps.origin, EV_PLAYER_TELEPORT_IN );
 		tent->s.clientNum = ent->s.clientNum;
@@ -1405,6 +1661,9 @@ void ClientBegin( int clientNum ) {
 			trap_SendServerCommand( -1, va("print \"%s" S_COLOR_WHITE " entered the game\n\"", client->pers.netname) );
 		}
 	}
+        
+        motd ( ent );
+        
 	G_LogPrintf( "ClientBegin: %i\n", clientNum );
 
 	//Send domination point names:
@@ -1413,8 +1672,14 @@ void ClientBegin( int clientNum ) {
 		DominationPointStatusMessage(ent);
 	}
 
+        TeamCvarSet();
+
 	// count current clients and rank for scoreboard
 	CalculateRanks();
+
+        //Send the list of custom vote options:
+        if(strlen(custom_vote_info))
+            SendCustomVoteCommands(clientNum);
 }
 
 /*
@@ -1435,10 +1700,12 @@ void ClientSpawn(gentity_t *ent) {
 	clientSession_t		savedSess;
 	int		persistant[MAX_PERSISTANT];
 	gentity_t	*spawnPoint;
+	//gentity_t *tent;
 	int		flags;
 	int		savedPing;
 //	char	*savedAreaBits;
-	int		accuracy_hits, accuracy_shots;
+	int		accuracy_hits, accuracy_shots,vote;
+        int		accuracy[WP_NUM_WEAPONS][2];
 	int		eventSequence;
 	char	userinfo[MAX_INFO_STRING];
 
@@ -1468,7 +1735,10 @@ void ClientSpawn(gentity_t *ent) {
 		{	
 			client->sess.spectatorState = SPECTATOR_FREE;
 			client->isEliminated = qtrue;
+                        if(g_gametype.integer == GT_LMS)
+                                G_LogPrintf( "LMS: %i %i %i: Player \"%s^7\" eliminated!\n", level.roundNumber, index, 1, client->pers.netname );
 			client->ps.pm_type = PM_SPECTATOR;
+                        CalculateRanks();
 			return;
 		}
 		else
@@ -1477,8 +1747,15 @@ void ClientSpawn(gentity_t *ent) {
 			client->sess.spectatorState = SPECTATOR_NOT;
 			client->ps.pm_type = PM_NORMAL;
 			client->isEliminated = qfalse;
+                        CalculateRanks();
 		}
-	}
+	} else {
+            //Force false.
+            if(client->isEliminated) {
+                client->isEliminated = qfalse;
+                CalculateRanks();
+            }
+        }
 
 	if(g_gametype.integer == GT_LMS && client->sess.sessionTeam != TEAM_SPECTATOR && (!level.intermissiontime || level.warmupTime != 0))
 	{
@@ -1489,6 +1766,7 @@ void ClientSpawn(gentity_t *ent) {
 				client->isEliminated = qtrue;
 				if((g_lms_mode.integer == 2 || g_lms_mode.integer == 3) && level.roundNumber == level.roundNumberStarted)
 					LMSpoint();
+                                G_LogPrintf( "LMS: %i %i %i: Player \"%s^7\" eliminated!\n", level.roundNumber, index, 1, client->pers.netname );
 			}
 			client->ps.pm_type = PM_SPECTATOR;
 			return;
@@ -1509,8 +1787,8 @@ void ClientSpawn(gentity_t *ent) {
 		spawnPoint = SelectSpectatorSpawnPoint ( spawn_origin, spawn_angles);
 	} else if (g_gametype.integer == GT_DOUBLE_D) {
 		//Double Domination uses special spawn points:
-		spawnPoint = SelectDoubleDominationSpawnPoint (spawn_origin, spawn_angles);
-	} else if (g_gametype.integer >= GT_CTF && g_ffa_gt==0) {
+		spawnPoint = SelectDoubleDominationSpawnPoint (client->sess.sessionTeam, spawn_origin, spawn_angles);
+	} else if (g_gametype.integer >= GT_CTF && g_ffa_gt==0 && g_gametype.integer!= GT_DOMINATION) {
 		// all base oriented team games use the CTF spawn points
 		spawnPoint = SelectCTFSpawnPoint ( 
 						client->sess.sessionTeam, 
@@ -1532,7 +1810,15 @@ void ClientSpawn(gentity_t *ent) {
 			// Tim needs to prevent bots from spawning at the initial point
 			// on q3dm0...
 			if ( ( spawnPoint->flags & FL_NO_BOTS ) && ( ent->r.svFlags & SVF_BOT ) ) {
+                            //Sago: The game has a tendency to select the furtest spawn point
+                            //This is a problem if the fursest spawnpoint keeps being NO_BOTS and it does!
+                            //This is a hot fix that seeks a spawn point faraway from the the currently found one
+                            vec3_t old_origin;
+                            VectorCopy(spawn_origin,old_origin);
+                            spawnPoint = SelectSpawnPoint (old_origin, spawn_origin, spawn_angles);
+                            if ( ( spawnPoint->flags & FL_NO_BOTS ) && ( ent->r.svFlags & SVF_BOT ) ) {
 				continue;	// try again
+                            }
 			}
 			// just to be symetric, we have a nohumans option...
 			if ( ( spawnPoint->flags & FL_NO_HUMANS ) && !( ent->r.svFlags & SVF_BOT ) ) {
@@ -1565,12 +1851,13 @@ void ClientSpawn(gentity_t *ent) {
 	saved = client->pers;
 	savedSess = client->sess;
 	savedPing = client->ps.ping;
+	vote = client->vote;
 //	savedAreaBits = client->areabits;
 	accuracy_hits = client->accuracy_hits;
 	accuracy_shots = client->accuracy_shots;
-	for ( i = 0 ; i < MAX_PERSISTANT ; i++ ) {
-		persistant[i] = client->ps.persistant[i];
-	}
+    memcpy(accuracy,client->accuracy,sizeof(accuracy));
+
+    memcpy(persistant,client->ps.persistant,MAX_PERSISTANT*sizeof(int));
 	eventSequence = client->ps.eventSequence;
 
 	Com_Memset (client, 0, sizeof(*client));
@@ -1578,9 +1865,15 @@ void ClientSpawn(gentity_t *ent) {
 	client->pers = saved;
 	client->sess = savedSess;
 	client->ps.ping = savedPing;
+	client->vote = vote;
 //	client->areabits = savedAreaBits;
 	client->accuracy_hits = accuracy_hits;
 	client->accuracy_shots = accuracy_shots;
+        for( i = 0 ; i < WP_NUM_WEAPONS ; i++ ){
+		client->accuracy[i][0] = accuracy[i][0];
+		client->accuracy[i][1] = accuracy[i][1];
+	}
+
 	client->lastkilled_client = -1;
 
 	for ( i = 0 ; i < MAX_PERSISTANT ; i++ ) {
@@ -1623,7 +1916,7 @@ void ClientSpawn(gentity_t *ent) {
 
 	client->ps.clientNum = index;
 
-if(g_gametype.integer != GT_ELIMINATION && g_gametype.integer != GT_CTF_ELIMINATION && g_gametype.integer != GT_LMS)
+if(g_gametype.integer != GT_ELIMINATION && g_gametype.integer != GT_CTF_ELIMINATION && g_gametype.integer != GT_LMS && !g_elimination_allgametypes.integer)
 {
 	client->ps.stats[STAT_WEAPONS] = ( 1 << WP_MACHINEGUN );
 	if ( g_gametype.integer == GT_TEAM ) {
@@ -1676,7 +1969,9 @@ else
 		client->ps.stats[STAT_WEAPONS] |= ( 1 << WP_BFG );
 		client->ps.ammo[WP_BFG] = g_elimination_bfg.integer;
 	}
-#ifdef MISSIONPACK
+        if (g_elimination_grapple.integer) {
+		client->ps.stats[STAT_WEAPONS] |= ( 1 << WP_GRAPPLING_HOOK );
+	}
 	if (g_elimination_nail.integer > 0) {
 		client->ps.stats[STAT_WEAPONS] |= ( 1 << WP_NAILGUN );
 		client->ps.ammo[WP_NAILGUN] = g_elimination_nail.integer;
@@ -1689,7 +1984,6 @@ else
 		client->ps.stats[STAT_WEAPONS] |= ( 1 << WP_CHAINGUN );
 		client->ps.ammo[WP_CHAINGUN] = g_elimination_chain.integer;
 	}
-#endif
 	
 	ent->health = client->ps.stats[STAT_ARMOR] = g_elimination_startArmor.integer; //client->ps.stats[STAT_MAX_HEALTH]*2;
 	ent->health = client->ps.stats[STAT_HEALTH] = g_elimination_startHealth.integer; //client->ps.stats[STAT_MAX_HEALTH]*2;	
@@ -1766,7 +2060,7 @@ else
 		// spawn given items have fired
 		client->ps.weapon = 1;
 		for ( i = WP_NUM_WEAPONS - 1 ; i > 0 ; i-- ) {
-			if ( client->ps.stats[STAT_WEAPONS] & ( 1 << i ) ) {
+			if ( client->ps.stats[STAT_WEAPONS] & ( 1 << i ) && i !=WP_GRAPPLING_HOOK ) {
 				client->ps.weapon = i;
 				break;
 			}
@@ -1792,6 +2086,11 @@ else
 
 	// clear entity state values
 	BG_PlayerStateToEntityState( &client->ps, &ent->s, qtrue );
+
+        if(g_spawnprotect.integer)
+            client->spawnprotected = qtrue;
+
+        RespawnTimeMessage(ent,0);
 }
 
 
@@ -1809,8 +2108,8 @@ server system housekeeping.
 */
 void ClientDisconnect( int clientNum ) {
 	gentity_t	*ent;
-	gentity_t	*tent;
 	int			i;
+        char	userinfo[MAX_INFO_STRING];
 
 	// cleanup if we are kicking a bot that
 	// hasn't spawned yet
@@ -1821,6 +2120,12 @@ void ClientDisconnect( int clientNum ) {
 		return;
 	}
 
+        ClientLeaving( clientNum);
+    //KK-OAX Admin
+    G_admin_namelog_update( ent->client, qtrue );
+    
+        trap_GetUserinfo( clientNum, userinfo, sizeof( userinfo ) );
+
 	// stop any following clients
 	for ( i = 0 ; i < level.maxclients ; i++ ) {
 		if ( (level.clients[i].sess.sessionTeam == TEAM_SPECTATOR || level.clients[i].ps.pm_type == PM_SPECTATOR)
@@ -1831,7 +2136,10 @@ void ClientDisconnect( int clientNum ) {
 	}
 
 	// send effect if they were completely connected
-	if ( ent->client->pers.connected == CON_CONNECTED 
+        /*
+         *Sago: I have removed this. A little dangerous but I make him suicide in a moment.
+         */
+	/*if ( ent->client->pers.connected == CON_CONNECTED
 		&& ent->client->sess.sessionTeam != TEAM_SPECTATOR ) {
 		tent = G_TempEntity( ent->client->ps.origin, EV_PLAYER_TELEPORT_OUT );
 		tent->s.clientNum = ent->s.clientNum;
@@ -1839,15 +2147,36 @@ void ClientDisconnect( int clientNum ) {
 		// They don't get to take powerups with them!
 		// Especially important for stuff like CTF flags
 		TossClientItems( ent );
-#ifdef MISSIONPACK
 		TossClientPersistantPowerups( ent );
-		if( g_gametype.integer == GT_HARVESTER ) {
+                if( g_gametype.integer == GT_HARVESTER ) {
 			TossClientCubes( ent );
 		}
-#endif
+//#endif
 
+	}*/
+
+        //Is the player alive?
+        i = (ent->client->ps.stats[STAT_HEALTH]>0);
+        //Commit suicide!
+        if ( ent->client->pers.connected == CON_CONNECTED
+		&& ent->client->sess.sessionTeam != TEAM_SPECTATOR && i ) {
+                //Prevent a team from loosing point because of player leaving
+                int teamscore = 0;
+                if(g_gametype.integer == GT_TEAM)
+                    teamscore = level.teamScores[ ent->client->sess.sessionTeam ];
+		// Kill him (makes sure he loses flags, etc)
+		ent->flags &= ~FL_GODMODE;
+		ent->client->ps.stats[STAT_HEALTH] = ent->health = 0;
+		player_die (ent, ent, g_entities + ENTITYNUM_WORLD, 100000, MOD_SUICIDE);
+                if(g_gametype.integer == GT_TEAM)
+                    level.teamScores[ ent->client->sess.sessionTeam ] = teamscore;
 	}
 
+
+
+        if ( ent->client->pers.connected == CON_CONNECTED && ent->client->sess.sessionTeam != TEAM_SPECTATOR)
+            PlayerStore_store(Info_ValueForKey(userinfo,"cl_guid"),ent->client->ps);
+
 	G_LogPrintf( "ClientDisconnect: %i\n", clientNum );
 
 	// if we are playing in tourney mode and losing, give a win to the other player
@@ -1879,6 +2208,7 @@ void ClientDisconnect( int clientNum ) {
 	trap_SetConfigstring( CS_PLAYERS + clientNum, "");
 
 	CalculateRanks();
+        CountVotes();
 
 	if ( ent->r.svFlags & SVF_BOT ) {
 		BotAIShutdownClient( clientNum, qfalse );
