@@ -85,6 +85,10 @@ qboolean CheckGauntletAttack( gentity_t *ent ) {
 		return qfalse;
 	}
 
+	if ( ent->client->noclip ) {
+		return qfalse;
+	}
+
 	traceEnt = &g_entities[ tr.entityNum ];
 
 	// send blood impact
@@ -105,14 +109,12 @@ qboolean CheckGauntletAttack( gentity_t *ent ) {
 	} else {
 		s_quadFactor = 1;
 	}
-#ifdef MISSIONPACK
 	if( ent->client->persistantPowerup && ent->client->persistantPowerup->item && ent->client->persistantPowerup->item->giTag == PW_DOUBLER ) {
 		s_quadFactor *= 2;
 	}
-#endif
 
 	if(g_instantgib.integer)
-		damage = 1000; //High damage in instant gib (normally enough to gib)
+		damage = 500; //High damage in instant gib (normally enough to gib)
 	else
 		damage = 50 * s_quadFactor;
 	G_Damage( traceEnt, ent, ent, forward, tr.endpos,
@@ -148,9 +150,9 @@ void SnapVectorTowards( vec3_t v, vec3_t to ) {
 
 	for ( i = 0 ; i < 3 ; i++ ) {
 		if ( to[i] <= v[i] ) {
-			v[i] = (int)v[i];
+			v[i] = floor(v[i]);
 		} else {
-			v[i] = (int)v[i] + 1;
+			v[i] = ceil(v[i]);
 		}
 	}
 }
@@ -182,9 +184,7 @@ void SnapVectorTowards( vec3_t v, vec3_t to ) {
 }
 //unlagged - attack prediction #3
 
-#ifdef MISSIONPACK
-#define CHAINGUN_SPREAD		600
-#endif
+#define CHAINGUN_SPREAD		600.0
 #define MACHINEGUN_SPREAD	200
 #define	MACHINEGUN_DAMAGE	7
 #define	MACHINEGUN_TEAM_DAMAGE	5		// wimpier MG in teamplay
@@ -192,9 +192,7 @@ void SnapVectorTowards( vec3_t v, vec3_t to ) {
 void Bullet_Fire (gentity_t *ent, float spread, int damage ) {
 	trace_t		tr;
 	vec3_t		end;
-#ifdef MISSIONPACK
 	vec3_t		impactpoint, bouncedir;
-#endif
 	float		r;
 	float		u;
 	gentity_t	*tent;
@@ -272,7 +270,6 @@ void Bullet_Fire (gentity_t *ent, float spread, int damage ) {
 		tent->s.otherEntityNum = ent->s.number;
 
 		if ( traceEnt->takedamage) {
-#ifdef MISSIONPACK
 			if ( traceEnt->client && traceEnt->client->invulnerabilityTime > level.time ) {
 				if (G_InvulnerabilityEffect( traceEnt, forward, tr.endpos, impactpoint, bouncedir )) {
 					G_BounceProjectile( muzzle, impactpoint, bouncedir, end );
@@ -287,12 +284,19 @@ void Bullet_Fire (gentity_t *ent, float spread, int damage ) {
 				continue;
 			}
 			else {
-#endif
+                            if(spread == CHAINGUN_SPREAD)
+                            {
+                                G_Damage( traceEnt, ent, ent, forward, tr.endpos,
+					damage, 0, MOD_CHAINGUN);
+                                ent->client->accuracy[WP_CHAINGUN][1]++;
+                            }
+                            else
+                            {
 				G_Damage( traceEnt, ent, ent, forward, tr.endpos,
 					damage, 0, MOD_MACHINEGUN);
-#ifdef MISSIONPACK
+                                ent->client->accuracy[WP_MACHINEGUN][1]++;
+                            }
 			}
-#endif
 		}
 		break;
 	}
@@ -334,9 +338,7 @@ qboolean ShotgunPellet( vec3_t start, vec3_t end, gentity_t *ent ) {
 	trace_t		tr;
 	int			damage, i, passent;
 	gentity_t	*traceEnt;
-#ifdef MISSIONPACK
 	vec3_t		impactpoint, bouncedir;
-#endif
 	vec3_t		tr_start, tr_end;
 
 	passent = ent->s.number;
@@ -353,7 +355,6 @@ qboolean ShotgunPellet( vec3_t start, vec3_t end, gentity_t *ent ) {
 
 		if ( traceEnt->takedamage) {
 			damage = DEFAULT_SHOTGUN_DAMAGE * s_quadFactor;
-#ifdef MISSIONPACK
 			if ( traceEnt->client && traceEnt->client->invulnerabilityTime > level.time ) {
 				if (G_InvulnerabilityEffect( traceEnt, forward, tr.endpos, impactpoint, bouncedir )) {
 					G_BounceProjectile( tr_start, impactpoint, bouncedir, tr_end );
@@ -374,12 +375,6 @@ qboolean ShotgunPellet( vec3_t start, vec3_t end, gentity_t *ent ) {
 					return qtrue;
 				}
 			}
-#else
-			G_Damage( traceEnt, ent, ent, forward, tr.endpos,	damage, 0, MOD_SHOTGUN);
-				if( LogAccuracyHit( traceEnt, ent ) ) {
-					return qtrue;
-				}
-#endif
 		}
 		return qfalse;
 	}
@@ -425,6 +420,8 @@ void ShotgunPattern( vec3_t origin, vec3_t origin2, int seed, gentity_t *ent ) {
 			ent->client->accuracy_hits++;
 		}
 	}
+        if( hitClient )
+            ent->client->accuracy[WP_SHOTGUN][1]++;
 
 //unlagged - backward reconciliation #2
 	// put them back
@@ -528,9 +525,7 @@ weapon_railgun_fire
 #define	MAX_RAIL_HITS	4
 void weapon_railgun_fire (gentity_t *ent) {
 	vec3_t		end;
-#ifdef MISSIONPACK
 	vec3_t impactpoint, bouncedir;
-#endif
 	trace_t		trace;
 	gentity_t	*tent;
 	gentity_t	*traceEnt;
@@ -543,7 +538,7 @@ void weapon_railgun_fire (gentity_t *ent) {
 
 	damage = 100 * s_quadFactor;
 	if(g_instantgib.integer)
-		damage = 5000;
+		damage = 800;
 
 	VectorMA (muzzle, 8192, forward, end);
 
@@ -563,7 +558,6 @@ void weapon_railgun_fire (gentity_t *ent) {
 		}
 		traceEnt = &g_entities[ trace.entityNum ];
 		if ( traceEnt->takedamage ) {
-#ifdef MISSIONPACK
 			if ( traceEnt->client && traceEnt->client->invulnerabilityTime > level.time ) {
 				if ( G_InvulnerabilityEffect( traceEnt, forward, trace.endpos, impactpoint, bouncedir ) ) {
 					G_BounceProjectile( muzzle, impactpoint, bouncedir, end );
@@ -590,12 +584,6 @@ void weapon_railgun_fire (gentity_t *ent) {
 				}
 				G_Damage (traceEnt, ent, ent, forward, trace.endpos, damage, 0, MOD_RAILGUN);
 			}
-#else
-				if( LogAccuracyHit( traceEnt, ent ) ) {
-					hits++;
-				}
-				G_Damage (traceEnt, ent, ent, forward, trace.endpos, damage, 0, MOD_RAILGUN);
-#endif
 		}
 		if ( trace.contents & CONTENTS_SOLID ) {
 			break;		// we hit something solid enough to stop the beam
@@ -650,12 +638,16 @@ void weapon_railgun_fire (gentity_t *ent) {
 		if ( ent->client->accurateCount >= 2 ) {
 			ent->client->accurateCount -= 2;
 			ent->client->ps.persistant[PERS_IMPRESSIVE_COUNT]++;
-			// add the sprite over the player's head
+                        G_LogPrintf( "Award: %i %i: %s gained the %s award!\n", ent->client->ps.clientNum, 2, ent->client->pers.netname, "IMPRESSIVE" );
+                        if(!level.hadBots) //There has not been any bots
+                            ChallengeMessage(ent,AWARD_IMPRESSIVE);
+                        // add the sprite over the player's head
 			ent->client->ps.eFlags &= ~(EF_AWARD_IMPRESSIVE | EF_AWARD_EXCELLENT | EF_AWARD_GAUNTLET | EF_AWARD_ASSIST | EF_AWARD_DEFEND | EF_AWARD_CAP );
 			ent->client->ps.eFlags |= EF_AWARD_IMPRESSIVE;
 			ent->client->rewardTime = level.time + REWARD_SPRITE_TIME;
 		}
 		ent->client->accuracy_hits++;
+                ent->client->accuracy[WP_RAILGUN][1]++;
 	}
 
 }
@@ -712,18 +704,11 @@ LIGHTNING GUN
 void Weapon_LightningFire( gentity_t *ent ) {
 	trace_t		tr;
 	vec3_t		end;
-#ifdef MISSIONPACK
 	vec3_t impactpoint, bouncedir;
-#endif
 	gentity_t	*traceEnt, *tent;
 	int			damage, i, passent;
 
-//Sago: This sound like a workaround for the lightning killing people before they know it
-//unlagged - server options
-	// this is configurable now
-//	damage = 8 * s_quadFactor;
-	damage = g_lightningDamage.integer * s_quadFactor;
-//unlagged - server options
+	damage = 8 * s_quadFactor;
 
 	passent = ent->s.number;
 	for (i = 0; i < 10; i++) {
@@ -742,7 +727,6 @@ void Weapon_LightningFire( gentity_t *ent ) {
 	G_UndoTimeShiftFor( ent );
 //unlagged - backward reconciliation #2
 
-#ifdef MISSIONPACK
 		// if not the first trace (the lightning bounced of an invulnerability sphere)
 		if (i) {
 			// add bounced off lightning bolt temp entity
@@ -753,7 +737,6 @@ void Weapon_LightningFire( gentity_t *ent ) {
 			SnapVector( end );
 			VectorCopy( end, tent->s.origin2 );
 		}
-#endif
 		if ( tr.entityNum == ENTITYNUM_NONE ) {
 			return;
 		}
@@ -761,7 +744,6 @@ void Weapon_LightningFire( gentity_t *ent ) {
 		traceEnt = &g_entities[ tr.entityNum ];
 
 		if ( traceEnt->takedamage) {
-#ifdef MISSIONPACK
 			if ( traceEnt->client && traceEnt->client->invulnerabilityTime > level.time ) {
 				if (G_InvulnerabilityEffect( traceEnt, forward, tr.endpos, impactpoint, bouncedir )) {
 					G_BounceProjectile( muzzle, impactpoint, bouncedir, end );
@@ -781,10 +763,6 @@ void Weapon_LightningFire( gentity_t *ent ) {
 				G_Damage( traceEnt, ent, ent, forward, tr.endpos,
 					damage, 0, MOD_LIGHTNING);
 			}
-#else
-				G_Damage( traceEnt, ent, ent, forward, tr.endpos,
-					damage, 0, MOD_LIGHTNING);
-#endif
 		}
 
 		if ( traceEnt->takedamage && traceEnt->client ) {
@@ -794,6 +772,7 @@ void Weapon_LightningFire( gentity_t *ent ) {
 			tent->s.weapon = ent->s.weapon;
 			if( LogAccuracyHit( traceEnt, ent ) ) {
 				ent->client->accuracy_hits++;
+                                ent->client->accuracy[WP_LIGHTNING][1]++;
 			}
 		} else if ( !( tr.surfaceFlags & SURF_NOIMPACT ) ) {
 			tent = G_TempEntity( tr.endpos, EV_MISSILE_MISS );
@@ -804,7 +783,6 @@ void Weapon_LightningFire( gentity_t *ent ) {
 	}
 }
 
-#ifdef MISSIONPACK
 /*
 ======================================================================
 
@@ -849,7 +827,6 @@ void weapon_proxlauncher_fire (gentity_t *ent) {
 //	VectorAdd( m->s.pos.trDelta, ent->client->ps.velocity, m->s.pos.trDelta );	// "real" physics
 }
 
-#endif
 
 //======================================================================
 
@@ -926,12 +903,6 @@ FireWeapon
 ===============
 */
 void FireWeapon( gentity_t *ent ) {
-
-
-	//If elimination warmup, don't fire at all!
-	//if (g_gametype.integer == GT_ELIMINATION && level.roundStartTime>level.time )
-	//	return;
-
 	//Make people drop out of follow mode (this should be moved, so people can change betwean players.)
 	if (ent->client->sess.spectatorState == SPECTATOR_FOLLOW) {
 		StopFollowing( ent );
@@ -943,23 +914,22 @@ void FireWeapon( gentity_t *ent ) {
 	} else {
 		s_quadFactor = 1;
 	}
-#ifdef MISSIONPACK
 	if( ent->client->persistantPowerup && ent->client->persistantPowerup->item && ent->client->persistantPowerup->item->giTag == PW_DOUBLER ) {
 		s_quadFactor *= 2;
 	}
-#endif
+
+        if (ent->client->spawnprotected)
+            ent->client->spawnprotected = qfalse;
 
 	// track shots taken for accuracy tracking.  Grapple is not a weapon and gauntet is just not tracked
 	if( ent->s.weapon != WP_GRAPPLING_HOOK && ent->s.weapon != WP_GAUNTLET ) {
-#ifdef MISSIONPACK
 		if( ent->s.weapon == WP_NAILGUN ) {
 			ent->client->accuracy_shots += NUM_NAILSHOTS;
+                        ent->client->accuracy[WP_NAILGUN][0]++;
 		} else {
 			ent->client->accuracy_shots++;
+                        ent->client->accuracy[ent->s.weapon][0]++;
 		}
-#else
-		ent->client->accuracy_shots++;
-#endif
 	}
 
 	// set aiming directions
@@ -1003,7 +973,6 @@ void FireWeapon( gentity_t *ent ) {
 	case WP_GRAPPLING_HOOK:
 		Weapon_GrapplingHook_Fire( ent );
 		break;
-#ifdef MISSIONPACK
 	case WP_NAILGUN:
 		Weapon_Nailgun_Fire( ent );
 		break;
@@ -1013,7 +982,6 @@ void FireWeapon( gentity_t *ent ) {
 	case WP_CHAINGUN:
 		Bullet_Fire( ent, CHAINGUN_SPREAD, MACHINEGUN_DAMAGE );
 		break;
-#endif
 	default:
 // FIXME		G_Error( "Bad ent->s.weapon" );
 		break;
@@ -1021,8 +989,6 @@ void FireWeapon( gentity_t *ent ) {
 }
 
 
-#ifdef MISSIONPACK
-
 /*
 ===============
 KamikazeRadiusDamage
@@ -1270,4 +1236,3 @@ void G_StartKamikaze( gentity_t *ent ) {
 	te->r.svFlags |= SVF_BROADCAST;
 	te->s.eventParm = GTS_KAMIKAZE;
 }
-#endif
