@@ -28,6 +28,10 @@ CREDITS
 =======================================================================
 */
 
+/*
+ *Sago 2008-06-29: This is kinda annoying and does not really give usefull information anyway
+ */
+
 
 #include "ui_local.h"
 
@@ -49,7 +53,8 @@ static sfxHandle_t UI_CreditMenu_Key( int key ) {
 		return 0;
 	}
 
-	trap_Cmd_ExecuteText( EXEC_APPEND, "quit\n" );
+        //Sago: I no longer show credits on close. Consider something else if ingame credits are to be made
+	//trap_Cmd_ExecuteText( EXEC_APPEND, "quit\n" );
 	return 0;
 }
 
@@ -67,8 +72,8 @@ static void UI_CreditMenu_Draw( void ) {
 	y += PROP_HEIGHT * PROP_SMALL_SIZE_SCALE;
 	UI_DrawProportionalString( 320, y, "Open Arena", UI_CENTER|UI_SMALLFONT, color_white );
 	
-	y += 28;
-	UI_DrawString( 320, y, "Click or press any key to quit", UI_CENTER|UI_SMALLFONT, color_red );
+	y += 228;
+	UI_DrawString( 320, y, "Terminating...", UI_CENTER|UI_SMALLFONT, color_red );
         
         y = 480 - PROP_HEIGHT * PROP_SMALL_SIZE_SCALE;
 	UI_DrawProportionalString( 320, y, "www.openarena.ws", UI_CENTER|UI_SMALLFONT, color_white );
@@ -87,4 +92,5 @@ void UI_CreditMenu( void ) {
 	s_credits.menu.key = UI_CreditMenu_Key;
 	s_credits.menu.fullscreen = qtrue;
 	UI_PushMenu ( &s_credits.menu );
+        trap_Cmd_ExecuteText( EXEC_APPEND, "wait 2; quit\n" );
 }
