@@ -33,10 +33,10 @@ DRIVER INFORMATION MENU
 */
 
 
-#define DRIVERINFO_FRAMEL	"menu/art/frame2_l"
-#define DRIVERINFO_FRAMER	"menu/art/frame1_r"
-#define DRIVERINFO_BACK0	"menu/art/back_0"
-#define DRIVERINFO_BACK1	"menu/art/back_1"
+#define DRIVERINFO_FRAMEL	"menu/art_blueish/frame2_l"
+#define DRIVERINFO_FRAMER	"menu/art_blueish/frame1_r"
+#define DRIVERINFO_BACK0	"menu/art_blueish/back_0"
+#define DRIVERINFO_BACK1	"menu/art_blueish/back_1"
 
 static char* driverinfo_artlist[] = 
 {
@@ -231,12 +231,12 @@ GRAPHICS OPTIONS MENU
 =======================================================================
 */
 
-#define GRAPHICSOPTIONS_FRAMEL	"menu/art/frame2_l"
-#define GRAPHICSOPTIONS_FRAMER	"menu/art/frame1_r"
-#define GRAPHICSOPTIONS_BACK0	"menu/art/back_0"
-#define GRAPHICSOPTIONS_BACK1	"menu/art/back_1"
-#define GRAPHICSOPTIONS_ACCEPT0	"menu/art/accept_0"
-#define GRAPHICSOPTIONS_ACCEPT1	"menu/art/accept_1"
+#define GRAPHICSOPTIONS_FRAMEL	"menu/art_blueish/frame2_l"
+#define GRAPHICSOPTIONS_FRAMER	"menu/art_blueish/frame1_r"
+#define GRAPHICSOPTIONS_BACK0	"menu/art_blueish/back_0"
+#define GRAPHICSOPTIONS_BACK1	"menu/art_blueish/back_1"
+#define GRAPHICSOPTIONS_ACCEPT0	"menu/art_blueish/accept_0"
+#define GRAPHICSOPTIONS_ACCEPT1	"menu/art_blueish/accept_1"
 
 #define ID_BACK2		101
 #define ID_FULLSCREEN	102
@@ -247,6 +247,7 @@ GRAPHICS OPTIONS MENU
 #define ID_DISPLAY		107
 #define ID_SOUND		108
 #define ID_NETWORK		109
+#define ID_RATIO                110
 
 typedef struct {
 	menuframework_s	menu;
@@ -261,6 +262,7 @@ typedef struct {
 	menutext_s		network;
 
 	menulist_s		list;
+        menulist_s              ratio;
 	menulist_s		mode;
 	menulist_s		driver;
 	menuslider_s	tq;
@@ -270,7 +272,6 @@ typedef struct {
         menulist_s  	bloom;
 	menulist_s  	allow_extensions;
 	menulist_s  	texturebits;
-	menulist_s  	colordepth;
 	menulist_s  	geometry;
 	menulist_s  	filter;
         menulist_s  	aniso;
@@ -288,7 +289,6 @@ typedef struct
 	int lighting;
         qboolean flares;
         qboolean bloom;
-	int colordepth;
 	int texturebits;
 	int geometry;
 	int filter;
@@ -303,22 +303,22 @@ static graphicsoptions_t		s_graphicsoptions;
 static InitialVideoOptions_s s_ivo_templates[] =
 {
 	{
-		6, qtrue, 3, 0, qfalse,qfalse, 2, 2, 2, 1, 0, 0, qtrue
+		6, qtrue, 3, 0, qfalse,qfalse, 2, 2, 1, 0, 0, qtrue
 	},
 	{
-		4, qtrue, 2, 0, qfalse,qfalse, 2, 2, 1, 1, 0, 0, qtrue	// JDC: this was tq 3
+		4, qtrue, 2, 0, qfalse,qfalse, 2, 1, 1, 0, 0, qtrue	// JDC: this was tq 3
 	},
 	{
-		3, qtrue, 2, 0, qfalse,qfalse, 0, 0, 1, 0, 0, 0, qtrue
+		3, qtrue, 2, 0, qfalse,qfalse, 0, 1, 0, 0, 0, qtrue
 	},
 	{
-		2, qtrue, 1, 0, qfalse,qfalse, 1, 0, 0, 0, 0, 0, qtrue
+		2, qtrue, 1, 0, qfalse,qfalse, 0, 0, 0, 0, 0, qtrue
 	},
 	{
-		2, qtrue, 1, 1, qfalse,qfalse, 1, 0, 0, 0, 0, 0, qtrue
+		2, qtrue, 1, 1, qfalse,qfalse, 0, 0, 0, 0, 0, qtrue
 	},
 	{
-		3, qtrue, 1, 0, qfalse,qfalse, 0, 0, 1, 0, 0, 0, qtrue
+		3, qtrue, 1, 0, qfalse,qfalse, 0, 1, 0, 0, 0, qtrue
 	}
 };
 
@@ -337,12 +337,31 @@ static const char *builtinResolutions[ ] =
 	"1280x1024",
 	"1600x1200",
 	"2048x1536",
-	"856x480 wide screen",
+	"856x480",
 	NULL
 };
 
+static const char *knownRatios[ ][2] =
+{
+        { "1.25:1", "5:4"   },
+        { "1.33:1", "4:3"   },
+        { "1.50:1", "3:2"   },
+        { "1.56:1", "14:9"  },
+        { "1.60:1", "16:10" },
+        { "1.67:1", "5:3"   },
+        { "1.78:1", "16:9"  },
+        { NULL    , NULL    }
+};
+
+#define MAX_RESOLUTIONS 32
+
+static const char* ratios[ MAX_RESOLUTIONS ];
+static char ratioBuf[ MAX_RESOLUTIONS ][ 8 ];
+static int ratioToRes[ MAX_RESOLUTIONS ];
+static int resToRatio[ MAX_RESOLUTIONS ];
+
 static char resbuf[ MAX_STRING_CHARS ];
-static const char* detectedResolutions[ 32 ];
+static const char* detectedResolutions[ MAX_RESOLUTIONS ];
 
 static const char** resolutions = builtinResolutions;
 static qboolean resolutionsDetected = qfalse;
@@ -364,7 +383,7 @@ static int GraphicsOptions_FindBuiltinResolution( int mode )
 
 	for( i = 0; builtinResolutions[ i ]; i++ )
 	{
-		if( !strcmp( builtinResolutions[ i ], detectedResolutions[ mode ] ) )
+		if( !Q_stricmp( builtinResolutions[ i ], detectedResolutions[ mode ] ) )
 			return i;
 	}
 
@@ -388,13 +407,64 @@ static int GraphicsOptions_FindDetectedResolution( int mode )
 
 	for( i = 0; detectedResolutions[ i ]; i++ )
 	{
-		if( !strcmp( builtinResolutions[ mode ], detectedResolutions[ i ] ) )
+		if( !Q_stricmp( builtinResolutions[ mode ], detectedResolutions[ i ] ) )
 			return i;
 	}
 
 	return -1;
 }
 
+/*
+=================
+GraphicsOptions_GetAspectRatios
+=================
+*/
+static void GraphicsOptions_GetAspectRatios( void )
+{
+    int i, r;
+
+    // build ratio list from resolutions
+    for( r = 0; resolutions[r]; r++ )
+    {
+        int w, h;
+        char *x;
+        char str[ sizeof(ratioBuf[0]) ];
+
+        // calculate resolution's aspect ratio
+        x = strchr( resolutions[r], 'x' )+1;
+        
+        
+        Q_strncpyz( str, resolutions[r], x-resolutions[r] );
+        w = atoi( str );
+        h = atoi( x );
+        Com_sprintf( str, sizeof(str), "%.2f:1", (float)w / (float)h );
+        
+        // rename common ratios ("1.33:1" -> "4:3")
+        for( i = 0; knownRatios[i][0]; i++ ) {
+            if( !Q_stricmp( str, knownRatios[i][0] ) ) {
+                Q_strncpyz( str, knownRatios[i][1], sizeof( str ) );
+                break;
+            }
+        }
+
+        // add ratio to list if it is new
+        // establish res/ratio relationship
+        for( i = 0; ratioBuf[i][0]; i++ )
+        {
+            if( !Q_stricmp( str, ratioBuf[i] ) )
+                break;
+        }
+        if( !ratioBuf[i][0] )
+        {
+            Q_strncpyz( ratioBuf[i], str, sizeof(ratioBuf[i]) );
+            ratioToRes[i] = r;
+        }
+        ratios[r] = ratioBuf[r];
+        resToRatio[r] = i;
+    }
+    ratios[r] = NULL;
+}
+
 /*
 =================
 GraphicsOptions_GetInitialVideo
@@ -402,7 +472,6 @@ GraphicsOptions_GetInitialVideo
 */
 static void GraphicsOptions_GetInitialVideo( void )
 {
-	s_ivo.colordepth  = s_graphicsoptions.colordepth.curvalue;
 	s_ivo.driver      = s_graphicsoptions.driver.curvalue;
 	s_ivo.mode        = s_graphicsoptions.mode.curvalue;
 	s_ivo.fullscreen  = s_graphicsoptions.fs.curvalue;
@@ -417,6 +486,35 @@ static void GraphicsOptions_GetInitialVideo( void )
 	s_ivo.texturebits = s_graphicsoptions.texturebits.curvalue;
 }
 
+/*
+=================
+GraphicsOptions_GetResolutions
+=================
+*/
+static void GraphicsOptions_GetResolutions( void )
+{
+    Q_strncpyz(resbuf, UI_Cvar_VariableString("r_availableModes"), sizeof(resbuf));
+    if(*resbuf)
+    {
+        char* s = resbuf;
+        unsigned int i = 0;
+        while( s && i < sizeof(detectedResolutions)/sizeof(detectedResolutions[0])-1)
+        {
+            detectedResolutions[i++] = s;
+            s = strchr(s, ' ');
+            if( s )
+                *s++ = '\0';
+        }
+        detectedResolutions[ i ] = NULL;
+
+        if( i > 0 )
+        {
+            resolutions = detectedResolutions;
+            resolutionsDetected = qtrue;
+        }
+    }
+}
+
 /*
 =================
 GraphicsOptions_CheckConfig
@@ -428,11 +526,9 @@ static void GraphicsOptions_CheckConfig( void )
 
 	for ( i = 0; i < NUM_IVO_TEMPLATES-1; i++ )
 	{
-		if ( s_ivo_templates[i].colordepth != s_graphicsoptions.colordepth.curvalue )
-			continue;
 		if ( s_ivo_templates[i].driver != s_graphicsoptions.driver.curvalue )
 			continue;
-		if ( s_ivo_templates[i].mode != s_graphicsoptions.mode.curvalue )
+		if ( GraphicsOptions_FindDetectedResolution(s_ivo_templates[i].mode) != s_graphicsoptions.mode.curvalue )
 			continue;
 		if ( s_ivo_templates[i].fullscreen != s_graphicsoptions.fs.curvalue )
 			continue;
@@ -471,23 +567,12 @@ static void GraphicsOptions_UpdateMenuItems( void )
 	{
 		s_graphicsoptions.fs.curvalue = 1;
 		s_graphicsoptions.fs.generic.flags |= QMF_GRAYED;
-		s_graphicsoptions.colordepth.curvalue = 1;
 	}
 	else
 	{
 		s_graphicsoptions.fs.generic.flags &= ~QMF_GRAYED;
 	}
 
-	if ( s_graphicsoptions.fs.curvalue == 0 || s_graphicsoptions.driver.curvalue == 1 )
-	{
-		s_graphicsoptions.colordepth.curvalue = 0;
-		s_graphicsoptions.colordepth.generic.flags |= QMF_GRAYED;
-	}
-	else
-	{
-		s_graphicsoptions.colordepth.generic.flags &= ~QMF_GRAYED;
-	}
-
 	if ( s_graphicsoptions.allow_extensions.curvalue == 0 )
 	{
 		if ( s_graphicsoptions.texturebits.curvalue == 0 )
@@ -526,10 +611,6 @@ static void GraphicsOptions_UpdateMenuItems( void )
 	{
 		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
 	}
-	if ( s_ivo.colordepth != s_graphicsoptions.colordepth.curvalue )
-	{
-		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
-	}
 	if ( s_ivo.driver != s_graphicsoptions.driver.curvalue )
 	{
 		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
@@ -582,7 +663,12 @@ static void GraphicsOptions_ApplyChanges( void *unused, int notification )
 	if( resolutionsDetected )
 	{
 		// search for builtin mode that matches the detected mode
-		int mode = GraphicsOptions_FindBuiltinResolution( s_graphicsoptions.mode.curvalue );
+		int mode;
+		if ( s_graphicsoptions.mode.curvalue == -1
+			|| s_graphicsoptions.mode.curvalue >= sizeof(detectedResolutions)/sizeof(detectedResolutions[0]) )
+			s_graphicsoptions.mode.curvalue = 0;
+
+		mode = GraphicsOptions_FindBuiltinResolution( s_graphicsoptions.mode.curvalue );
 		if( mode == -1 )
 		{
 			char w[ 16 ], h[ 16 ];
@@ -604,6 +690,7 @@ static void GraphicsOptions_ApplyChanges( void *unused, int notification )
 	trap_Cvar_SetValue( "r_depthbits", 0 );
 	trap_Cvar_SetValue( "r_stencilbits", 0 );
 	trap_Cvar_SetValue( "r_vertexLight", s_graphicsoptions.lighting.curvalue );
+        trap_Cvar_SetValue( "cg_autovertex", s_graphicsoptions.lighting.curvalue );
         trap_Cvar_SetValue( "r_flares", s_graphicsoptions.flares.curvalue );
         trap_Cvar_SetValue( "r_bloom", s_graphicsoptions.bloom.curvalue );
         
@@ -659,6 +746,9 @@ static void GraphicsOptions_Event( void* ptr, int event ) {
 	}
 
 	switch( ((menucommon_s*)ptr)->id ) {
+        case ID_RATIO:
+            s_graphicsoptions.mode.curvalue = ratioToRes[ s_graphicsoptions.ratio.curvalue ];
+            // fall through to apply mode constraints
 	case ID_MODE:
 		// clamp 3dfx video modes
 		if ( s_graphicsoptions.driver.curvalue == 1 )
@@ -668,15 +758,16 @@ static void GraphicsOptions_Event( void* ptr, int event ) {
 			else if ( s_graphicsoptions.mode.curvalue > 6 )
 				s_graphicsoptions.mode.curvalue = 6;
 		}
+                s_graphicsoptions.ratio.curvalue = resToRatio[ s_graphicsoptions.mode.curvalue ];
 		break;
 
 	case ID_LIST:
 		ivo = &s_ivo_templates[s_graphicsoptions.list.curvalue];
 
-		s_graphicsoptions.mode.curvalue        = ivo->mode;
+		s_graphicsoptions.mode.curvalue        = GraphicsOptions_FindDetectedResolution(ivo->mode);
+                s_graphicsoptions.ratio.curvalue       = resToRatio[ s_graphicsoptions.mode.curvalue ];
 		s_graphicsoptions.tq.curvalue          = ivo->tq;
 		s_graphicsoptions.lighting.curvalue    = ivo->lighting;
-		s_graphicsoptions.colordepth.curvalue  = ivo->colordepth;
 		s_graphicsoptions.texturebits.curvalue = ivo->texturebits;
 		s_graphicsoptions.geometry.curvalue    = ivo->geometry;
 		s_graphicsoptions.filter.curvalue      = ivo->filter;
@@ -764,7 +855,7 @@ static void GraphicsOptions_SetMenuItems( void )
 
 			for(i = 0; detectedResolutions[i]; ++i)
 			{
-				if(!strcmp(buf, detectedResolutions[i]))
+				if(!Q_stricmp(buf, detectedResolutions[i]))
 				{
 					s_graphicsoptions.mode.curvalue = i;
 					break;
@@ -834,29 +925,6 @@ static void GraphicsOptions_SetMenuItems( void )
 	{
 		s_graphicsoptions.geometry.curvalue = 2;
 	}
-
-	switch ( ( int ) trap_Cvar_VariableValue( "r_colorbits" ) )
-	{
-	default:
-	case 0:
-		s_graphicsoptions.colordepth.curvalue = 0;
-		break;
-	case 16:
-		s_graphicsoptions.colordepth.curvalue = 1;
-		break;
-	case 32:
-		s_graphicsoptions.colordepth.curvalue = 2;
-		break;
-	}
-
-	if ( s_graphicsoptions.fs.curvalue == 0 )
-	{
-		s_graphicsoptions.colordepth.curvalue = 0;
-	}
-	if ( s_graphicsoptions.driver.curvalue == 1 )
-	{
-		s_graphicsoptions.colordepth.curvalue = 1;
-	}
 }
 
 /*
@@ -899,13 +967,6 @@ void GraphicsOptions_MenuInit( void )
 		NULL
 	};
 
-	static const char *colordepth_names[] =
-	{
-		"Default",
-		"16 bit",
-		"32 bit",
-		NULL
-	};
 
 	static const char *filter_names[] =
 	{
@@ -944,26 +1005,8 @@ void GraphicsOptions_MenuInit( void )
 	memset( &s_graphicsoptions, 0 ,sizeof(graphicsoptions_t) );
 
 
-	Q_strncpyz(resbuf, UI_Cvar_VariableString("r_availableModes"), sizeof(resbuf));
-	if(*resbuf)
-	{
-		char* s = resbuf;
-		unsigned int i = 0;
-		while( s && i < sizeof(detectedResolutions)/sizeof(detectedResolutions[0])-1)
-		{
-			detectedResolutions[i++] = s;
-			s = strchr(s, ' ');
-			if( s )
-				*s++ = '\0';
-		}
-		detectedResolutions[ i ] = NULL;
-
-		if( i > 0 )
-		{
-			resolutions = detectedResolutions;
-			resolutionsDetected = qtrue;
-		}
-	}
+        GraphicsOptions_GetResolutions();
+        GraphicsOptions_GetAspectRatios();
 
 	GraphicsOptions_Cache();
 
@@ -1034,7 +1077,7 @@ void GraphicsOptions_MenuInit( void )
 	s_graphicsoptions.network.style				= UI_RIGHT;
 	s_graphicsoptions.network.color				= color_red;
 
-	y = 240 - 6 * (BIGCHAR_HEIGHT + 2);
+	y = 240 - 7 * (BIGCHAR_HEIGHT + 2);
 	s_graphicsoptions.list.generic.type     = MTYPE_SPINCONTROL;
 	s_graphicsoptions.list.generic.name     = "Graphics Settings:";
 	s_graphicsoptions.list.generic.flags    = QMF_PULSEIFFOCUS|QMF_SMALLFONT;
@@ -1063,9 +1106,20 @@ void GraphicsOptions_MenuInit( void )
 	s_graphicsoptions.allow_extensions.itemnames        = enabled_names;
 	y += BIGCHAR_HEIGHT+2;
 
+        s_graphicsoptions.ratio.generic.type     = MTYPE_SPINCONTROL;
+        s_graphicsoptions.ratio.generic.name     = "Aspect Ratio:";
+        s_graphicsoptions.ratio.generic.flags    = QMF_PULSEIFFOCUS|QMF_SMALLFONT;
+        s_graphicsoptions.ratio.generic.x        = 400;
+        s_graphicsoptions.ratio.generic.y        = y;
+        s_graphicsoptions.ratio.itemnames        = ratios;
+        s_graphicsoptions.ratio.generic.callback = GraphicsOptions_Event;
+        s_graphicsoptions.ratio.generic.id       = ID_RATIO;
+        y += BIGCHAR_HEIGHT+2;
+
+
 	// references/modifies "r_mode"
 	s_graphicsoptions.mode.generic.type     = MTYPE_SPINCONTROL;
-	s_graphicsoptions.mode.generic.name     = "Video Mode:";
+	s_graphicsoptions.mode.generic.name     = "Resolution:";
 	s_graphicsoptions.mode.generic.flags    = QMF_PULSEIFFOCUS|QMF_SMALLFONT;
 	s_graphicsoptions.mode.generic.x        = 400;
 	s_graphicsoptions.mode.generic.y        = y;
@@ -1074,15 +1128,6 @@ void GraphicsOptions_MenuInit( void )
 	s_graphicsoptions.mode.generic.id       = ID_MODE;
 	y += BIGCHAR_HEIGHT+2;
 
-	// references "r_colorbits"
-	s_graphicsoptions.colordepth.generic.type     = MTYPE_SPINCONTROL;
-	s_graphicsoptions.colordepth.generic.name     = "Color Depth:";
-	s_graphicsoptions.colordepth.generic.flags    = QMF_PULSEIFFOCUS|QMF_SMALLFONT;
-	s_graphicsoptions.colordepth.generic.x        = 400;
-	s_graphicsoptions.colordepth.generic.y        = y;
-	s_graphicsoptions.colordepth.itemnames        = colordepth_names;
-	y += BIGCHAR_HEIGHT+2;
-
 	// references/modifies "r_fullscreen"
 	s_graphicsoptions.fs.generic.type     = MTYPE_SPINCONTROL;
 	s_graphicsoptions.fs.generic.name	  = "Fullscreen:";
@@ -1209,8 +1254,8 @@ void GraphicsOptions_MenuInit( void )
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.list );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.driver );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.allow_extensions );
+        Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.ratio );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.mode );
-	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.colordepth );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.fs );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.lighting );
         Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.flares );
