@@ -233,8 +233,8 @@ PROTOCOL
 
 //Open Arena up to 0.7.6 used 68
 //Open Arena 0.7.7 uses 69
-//Open Arena 0.8.0 uses protocol 70
-//Open Arena 0.8.1+ uses protocol 71 (Shouldn't have been bumped but was it anyway)
+//Open Arena 0.8.0 used protocol 70
+//Open Arena 0.8.1+ uses protocol 71
 #define	PROTOCOL_VERSION	71
 // 1.31 - 67
 
@@ -359,12 +359,9 @@ void	*VM_ExplicitArgPtr( vm_t *vm, intptr_t intValue );
 #define	VMA(x) VM_ArgPtr(args[x])
 static ID_INLINE float _vmf(intptr_t x)
 {
-	union {
-		intptr_t l;
-		float f;
-	} t;
-	t.l = x;
-	return t.f;
+	floatint_t fi;
+	fi.i = (int) x;
+	return fi.f;
 }
 #define	VMF(x)	_vmf(args[x])
 
@@ -532,7 +529,6 @@ char	*Cvar_InfoString_Big( int bit );
 // returns an info string containing all the cvars that have the given bit set
 // in their flags ( CVAR_USERINFO, CVAR_SERVERINFO, CVAR_SYSTEMINFO, etc )
 void	Cvar_InfoStringBuffer( int bit, char *buff, int buffsize );
-void Cvar_CheckRange( cvar_t *cv, float minVal, float maxVal, qboolean shouldBeIntegral );
 
 void	Cvar_Restart_f( void );
 
@@ -807,9 +803,7 @@ extern	cvar_t	*com_journal;
 extern	cvar_t	*com_cameraMode;
 extern	cvar_t	*com_ansiColor;
 extern	cvar_t	*com_unfocused;
-extern	cvar_t	*com_maxfpsUnfocused;
 extern	cvar_t	*com_minimized;
-extern	cvar_t	*com_maxfpsMinimized;
 extern	cvar_t	*com_altivec;
 
 // both client and server must agree to pause
